@@ -123,7 +123,12 @@ void refreshDirView()
  //show control message at the bottom
  fprintf(stdout, "\e[%d;%dH", h-1, y+1);
  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
- printf("[ENTER]: Open dir/file  [ARROWS]: Navigate  [ESC]: Cancel");
+ if(GNU_DOS_LEVEL > 2)
+    printf("[ENTER]: Open dir/file [C-p C-n C-f C-b]: Navigate [C-g]: Cancel");
+ else if(GNU_DOS_LEVEL > 1)
+    printf("[ENTER]: Open dir/file [C-p C-n C-f C-b]: Navigate [ESC]: Cancel");
+ else
+    printf("[ENTER]: Open dir/file  [ARROWS]: Navigate  [ESC]: Cancel");
  fprintf(stdout, "\e[%d;%dH", h-2, y+1);
  printf("File: ");
  //setScreenColors(WHITE, BGBLUE);
