@@ -1146,7 +1146,7 @@ void editMenu_Redo()
     totalLines += i;
     l = undo_action_start[last_undo_action].nline;
     //save the rest of the line to reattach it later
-    char *tmp = (char *) malloc(MAX_CHARS_PER_LINE*4);
+    char *tmp = (char *) malloc((MAX_CHARS_PER_LINE+TAB_CHARS)*4);
     strcpy(tmp, "");
     strcpy(tmp, lines[l]+(j*4));
     int ltmp = LINE_IS_LINKED[l];
@@ -1155,8 +1155,9 @@ void editMenu_Redo()
     {
       //if(j >= totalCharsInLine[l]) { l++; j = 0; }
       if(undo_text[last_undo_action][i] == '\n') 
-      { LINE_IS_LINKED[l] = 0; lines[l][j] = '\0'; l++; j = 0; i+=4; }
-      if(j > MAX_CHARS_PER_LINE*4) { LINE_IS_LINKED[l] = 1; l++; j = 0; }
+      { LINE_IS_LINKED[l] = 0; lines[l][j*4] = '\0'; l++; j = 0; i+=4; 
+	checkTabsInLine(l-1); }
+      if(j > MAX_CHARS_PER_LINE) { LINE_IS_LINKED[l] = 1; l++; j = 0; }
       if(l >= undo_action_end[last_undo_action].nline && j >= k) break;
       lines[l][j*4] = undo_text[last_undo_action][i];
       lines[l][j*4+1] = undo_text[last_undo_action][i+1];
@@ -1395,7 +1396,14 @@ void editMenu_Find()
     selectedChar = find_result_pos[i].nchar;
     refreshView();
     setScreenColors(FG_COLOR[COLOR_STATUS_BAR], BG_COLOR[COLOR_STATUS_BAR]);
-    printf("\e[%d;1HFind(%d/%d): [Up] Prev [Down] Next [ESC] Cancel",
+    if(GNU_DOS_LEVEL > 2)
+      printf("\e[%d;1HFind(%d/%d): [C-p] Prev [C-n] Next [C-g] Cancel",
+	   SCREEN_H, i+1, total_find_results);
+    else if(GNU_DOS_LEVEL > 1)
+      printf("\e[%d;1HFind(%d/%d): [C-p] Prev [C-n] Next [ESC] Cancel",
+	   SCREEN_H, i+1, total_find_results);
+    else
+      printf("\e[%d;1HFind(%d/%d): [Up] Prev [Down] Next [ESC] Cancel",
 	   SCREEN_H, i+1, total_find_results);
     fprintf(stdout, "\e[%d;%dH", selectedLine+3, selectedChar+2);
     fflush(stdout);
@@ -1404,17 +1412,35 @@ get_key:
     c = getKey();
     switch(c[0]) 
     {
+      case('p'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_up;
       case(UP_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	if(i <= 0) i = total_find_results-1;
 	else i--;
 	break;
+      case('n'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_down;
+      case(DOWN_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_down:
       case(ENTER_KEY):
       case(SPACE_KEY):
-      case(DOWN_KEY):
 	if(i >= total_find_results-1) i = 0;
 	else i++;
 	break;
+      case('g'):
+	if(GNU_DOS_LEVEL < 3) break;
+	if(!CTRL) break;
+	goto do_esc;
       case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	refreshView();
 	return;
 	break;
@@ -1490,7 +1516,11 @@ void editMenu_Replace()
     selectedChar = find_result_pos[i].nchar;
     refreshView();
     setScreenColors(FG_COLOR[COLOR_STATUS_BAR], BG_COLOR[COLOR_STATUS_BAR]);
-    printf("\e[%d;1HFind(%d/%d): [ENTER] Replace [A] Replace All [ESC] Cancel",
+    if(GNU_DOS_LEVEL > 2)
+      printf("\e[%d;1HFind(%d/%d): [ENTER] Replace [A] Replace All [C-g] Cancel",
+	   SCREEN_H, i+1, total_find_results);
+    else
+      printf("\e[%d;1HFind(%d/%d): [ENTER] Replace [A] Replace All [ESC] Cancel",
 	   SCREEN_H, i+1, total_find_results);
     fprintf(stdout, "\e[%d;%dH", selectedLine+3, selectedChar+2);
     fflush(stdout);
@@ -1499,15 +1529,33 @@ get_key:
     c = getKey();
     switch(c[0]) 
     {
+      case('p'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_up;
       case(UP_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	if(i <= 0) i = total_find_results-1;
 	else i--;
 	break;
+      case('n'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_down;
       case(DOWN_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	if(i >= total_find_results-1) i = 0;
 	else i++;
 	break;
+      case('g'):
+	if(GNU_DOS_LEVEL < 3) break;
+	if(!CTRL) break;
+	goto do_esc;
       case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	refreshView();
 	return;
 	break;
@@ -1846,7 +1894,7 @@ void checkTabsInLine(int pos)
 {
   int i, j, k, l;
   int carry = 0; 
-  char *tmp = (char *) malloc(MAX_CHARS_PER_LINE*4);
+  char *tmp = (char *) malloc((MAX_CHARS_PER_LINE+TAB_CHARS)*4);
   //here comes the real stuff
   for(l = 0; l < strlen(lines[pos]); l+=4)
     if(lines[pos][l] == '\t') 
@@ -1856,7 +1904,7 @@ void checkTabsInLine(int pos)
       carry += (j-1);
       
       int k = (strlen(lines[pos])/4)+carry;
-      char *t = (char *) malloc(MAX_CHARS_PER_LINE*4);
+      char *t = (char *) malloc((MAX_CHARS_PER_LINE+TAB_CHARS)*4);
       strcpy(t, lines[pos]);
       
       if((strlen(lines[pos])/4)+carry > MAX_CHARS_PER_LINE) 
@@ -1923,7 +1971,8 @@ void checkTabsInLine(int pos)
       totalCharsInLine[i] = 0;
       int carry = 0;
       for(j = 0; j < strlen(lines[i]); j+=4)
-	if(lines[i][j] == '\t') {
+	if(lines[i][j] == '\t') 
+	{
 	  k = TAB_CHARS-(((j/4)+carry)%TAB_CHARS); k=0?TAB_CHARS:k;
 	  totalCharsInLine[i] += k; carry += (k-1);
 	} else totalCharsInLine[i]++;
