@@ -27,9 +27,12 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <getopt.h>
+#include <asm/types.h>
 
 int NEW_GNU_DOS_LEVEL;
 struct passwd *pass;//will be used to find the home dir
+char *STARTUP_FILE_NAME;
 
 void exit_gracefully(int exit_code) 
 {
@@ -65,7 +68,7 @@ void exit_gracefully(int exit_code)
   return;
 
 good_to_go:
-  write_config_file();
+  //write_config_file();
   fcloseall();
   //remove backup file, if any
   //char *backup_file_name = (char *) malloc(strlen(open_file_name)+2);
@@ -80,7 +83,7 @@ good_to_go:
   exit(exit_code); 
 }
 
-void parseLineArgs(int argc, char *argv[]) 
+void parseLineArgs(int argc, char **argv) 
 {
   GNU_DOS_LEVEL = 1;
   NEW_FILE = 1;
@@ -89,6 +92,159 @@ void parseLineArgs(int argc, char *argv[])
   AUTO_HIGHLIGHTING = 0;
   NEW_GNU_DOS_LEVEL = 0;
   //struct passwd *pass;//will be used to find the home dir
+  
+	///////////////////////////////////////
+	//parse command line arguments
+	///////////////////////////////////////
+	int c;
+	char *file_name = NULL;
+	static int EXPORT_FLAG = 0;
+	static int LOG_FILE_SET = 0;
+	char *EXPORT_DIR, *EXPORT_FILE;
+	static struct option long_options[] =
+	{
+	 {"reset-config", no_argument,            0,  'r'},
+	 {"help",         no_argument,            0,  'h'},
+	 {"level",  required_argument,            0,  'l'},
+	 {"version",      no_argument,            0,  'v'},
+	 {0, 0, 0, 0}
+	};
+
+	while(1)
+	{
+		int option_index=0;
+		c = getopt_long(argc, argv, "rhl:v", long_options, &option_index);
+		if(c==-1) break;	//end of options
+
+		switch(c)
+		{
+		case 0:
+			break;
+		case 'r':	//reset config file
+		  if(!(pass = getpwuid(geteuid()))) 
+		  {
+		    printf("Error: couldn't open home directory to write "
+			   "configuration file.\n");
+		    printf("Aborting.\n");
+		    exit(1);
+		  }
+		  config_file_name = (char *) malloc(strlen(pass->pw_dir)+12);
+		  strcpy(config_file_name, pass->pw_dir);
+		  strcat(config_file_name, "/");
+		  strcat(config_file_name, ".mino.conf");
+		  if(!(config_file = fopen(config_file_name, "w"))) 
+		  {
+		    printf("Error: couldn't write to configuration file in "
+		           "home directory.\n");
+		    printf("Aborting.\n");
+		    exit(1);
+		  }
+		  printf("Resetting program configuration..\n");
+		  //write default values to the configuration file
+		  fprintf(config_file, "#Configuration file for mino program\n");
+		  fprintf(config_file, "#Please do not modify this file by hand\n");
+		  fprintf(config_file, "#Use the Options menu in mino to change"
+				       " program configuration.\n\n");
+		  //fprintf(config_file, "#Maximum number of dirs that can be handled in dialog boxes\n");
+		  //fprintf(config_file, "MAXDIRS = 255\n");
+		  //fprintf(config_file, "#Maximum number of files that can be handled in dialog boxes\n");
+		  //fprintf(config_file, "MAXFILES = 255\n");
+		  //fprintf(config_file, "#Maximum number of permitted lines in each document\n");
+		  //fprintf(config_file, "MAXLINES = 100\n\n");
+		  fprintf(config_file, "#Line Wrapping\n");
+		  fprintf(config_file, "#If TRUE, lines cannot be longer than"
+				       " the screen width\n");
+		  fprintf(config_file, "#If FALSE, lines cannot be upto "
+				       "MAX_CHARS_PER_LINE characters\n");
+		  fprintf(config_file, "#Note this value is omitted if "
+				       "WRAP_LINES is TRUE\n");
+		  fprintf(config_file, "MAX_CHARS_PER_LINE = 100\n");
+		  fprintf(config_file, "WRAP_LINES = TRUE\n\n");
+		  fprintf(config_file, "#Number of spaces to insert when user"
+				       " presses TAB key\n");
+		  fprintf(config_file, "TAB_CHARS = 8\n\n");
+		  fprintf(config_file, "#Default title for newly opened "
+				       "documents, no quotes\n");
+		  fprintf(config_file, "DEFAULT_TITLE = untitled\n\n");
+		  fprintf(config_file, "#Start mino with CAPS and INSERT set "
+				       "to OFF/ON\n");
+		  fprintf(config_file, "CAPS = OFF\n");
+		  fprintf(config_file, "INSERT = OFF\n\n");
+		  fprintf(config_file, "#Display colors\n");
+		  fprintf(config_file, "FG_COLOR_WIN = 37\n");
+		  fprintf(config_file, "FG_COLOR_HLT = 34\n");
+		  fprintf(config_file, "FG_COLOR_MBAR = 34\n");
+		  fprintf(config_file, "FG_COLOR_SBAR = 34\n");
+		  fprintf(config_file, "FG_COLOR_HBUT = 32\n");
+		  fprintf(config_file, "FG_COLOR_BUT = 37\n");
+		  fprintf(config_file, "BG_COLOR_WIN = 44\n");
+		  fprintf(config_file, "BG_COLOR_HLT = 47\n");
+		  fprintf(config_file, "BG_COLOR_MBAR = 47\n");
+		  fprintf(config_file, "BG_COLOR_SBAR = 47\n");
+		  fprintf(config_file, "BG_COLOR_HBUT = 41\n");
+		  fprintf(config_file, "BG_COLOR_BUT = 41\n");
+		  fprintf(config_file, "#Show README on startup\n");
+		  fprintf(config_file, "SHOW_README\n");
+		  fprintf(config_file, "#GnuDOS Level\n");
+		  fprintf(config_file, "GNU_DOS_LEVEL = 1\n");
+		  fprintf(config_file, "#Auto-indentation\n");
+		  fprintf(config_file, "AUTO_INDENT = 1\n");
+		  fclose(config_file);
+		  printf("Finished writing default values to ~/.mino.conf\n");
+		  exit(0);
+		  break;
+		case 'h':	//show program help
+		  printf("\nCommand line help for mino under GNU/Linux\n");
+		  printf("Copyright (C) Mohammed Isam 2014\n");
+		  printf("This is a GNU software, part of the GnuDOS package\n\n");
+		  printf("Usage: %s [filename][options]\n\n", argv[0]);
+		  printf("Options:\n");
+		  printf("\tfilename: File to be opened by mino (optional)\n");
+		  printf("\t--reset-config, -r\tReset program configuration. "
+			 "Writes default\n");
+		  printf("\t                  \tvalues to .mino.conf file\n");
+		  printf("\t--help, -h        \tShow this command line help\n");
+		  printf("\t--version, -v     \tShow program version\n");
+		  printf("\t--levelX, -lX     \tSet the experience level, where X is 1-6\n");
+		  printf("For more information, see 'info mino' or the README"
+			 " file in mino help menu\n");
+		  exit(0);
+		  break;
+		case 'v':	//show program version
+		  printf("Mino version 1.2\n");
+		  exit(0);
+		  break;
+		case 'l':	//set GNU_DOS level
+		  if(0) ;
+		  int i = atoi(optarg);
+		  if(i < 1 || i > 6)
+		  {
+			  printf("Unrecognised level. See 'man mino' or "
+				 "'info mino' for information about possible"
+				 " levels.\n");
+			  exit(1); break;
+		  }
+		  NEW_GNU_DOS_LEVEL = i;
+		  break;
+		case '?':
+			break;
+		default:
+			abort();
+		}
+	}
+	///////////////////////////////////////
+	//parse the remaining arguments
+	///////////////////////////////////////
+	while(optind < argc)
+	{
+	  NEW_FILE = 0; FILE_STATE = OPENED;
+	  open_file_at_startup = 1;
+	  STARTUP_FILE_NAME = (char *)malloc(strlen(argv[optind]));
+	  strcpy(STARTUP_FILE_NAME, argv[optind]);
+	  break;
+	}
+  
+  /*
   if(argc > 1) 
   {//if #1
    int i;
@@ -162,6 +318,8 @@ void parseLineArgs(int argc, char *argv[])
       fprintf(config_file, "SHOW_README\n");
       fprintf(config_file, "#GnuDOS Level\n");
       fprintf(config_file, "GNU_DOS_LEVEL = 1\n");
+      fprintf(config_file, "#Auto-indentation\n");
+      fprintf(config_file, "AUTO_INDENT = 1\n");
       fclose(config_file);
       printf("Finished writing default values to ~/.mino.conf\n");
       exit(0);
@@ -187,7 +345,7 @@ void parseLineArgs(int argc, char *argv[])
     else if(strcmp(argv[i], "--version") == 0
 	    || strcmp(argv[i], "-v") == 0) 
     {//if #3
-      printf("Mino version 1.1\n");
+      printf("Mino version 1.2\n");
       exit(0);
     }
     else 
@@ -197,6 +355,7 @@ void parseLineArgs(int argc, char *argv[])
       //return;
     }//end if #2
   }//end if #1
+  */
 }//end parseLineArgs()
 
 void init_error() 
@@ -218,6 +377,11 @@ void init_error()
  * **************************************/
 void init() 
 {
+  int i;
+  AUTO_INDENT = 1;
+  for(i=0; i<100; i++) AUTO_INDENT_STR[i] = '\0';
+  /////////////////////////////////////
+  
     //pass = malloc(sizeof(struct passwd));
     //struct passwd *pass;//will be used to find the home dir
     if(!(pass = getpwuid(geteuid()))) 
@@ -264,7 +428,8 @@ void init()
   //4. Options Menu//
   optionsMenu[0] = "Change colors  ";
   optionsMenu[1] = "Tab spaces     ";
-  optionsMenu[2] = "Reset config   ";
+  optionsMenu[2] = "Autoindent     ";
+  optionsMenu[3] = "Reset config   ";
   //5. Help Menu//
   helpMenu[0] = "View README    ";
   helpMenu[1] = "GNU Keybindings";
@@ -298,7 +463,6 @@ void init()
   BG_COLOR_ARRAY[7] = 47;
  SHOW_README = 0;
 
- int i;
  char buf[100];
  //read configuration file
  while(fgets(buf, sizeof(buf), config_file)) 
@@ -408,10 +572,21 @@ void init()
    else if (strstr(buf, "SHOW_README")) 
    {
      SHOW_README = 1;
+   }
+   else if (strstr(buf, "AUTO_INDENT")) 
+   {
+     AUTO_INDENT = atoi(strchr(buf, '=')+2);
   }//end if
  }//end while
+ 
  fclose(config_file);
  free(config_file_name);
+
+ 
+ if(AUTO_INDENT) optionsMenu[2] = strdup("Autoindent    *");
+ else optionsMenu[2] = strdup("Autoindent     ");
+ //else optionsMenu[2][14] = ' ';
+ 
  old_window_color = BG_COLOR[COLOR_WINDOW];
  if(NEW_GNU_DOS_LEVEL)
    GNU_DOS_LEVEL = NEW_GNU_DOS_LEVEL;
@@ -530,7 +705,9 @@ void init_built_in_defaults()
   //4. Options Menu//
   optionsMenu[0] = "Change colors  ";
   optionsMenu[1] = "Tab spaces     ";
-  optionsMenu[2] = "Reset config   ";
+  optionsMenu[2] = "Autoindent    *";
+  optionsMenu[3] = "Reset config   ";
+  
   //5. Help Menu//
   helpMenu[0] = "View README    ";
   helpMenu[1] = "GNU Keybindings";
@@ -567,9 +744,11 @@ void init_built_in_defaults()
   BG_COLOR[COLOR_HBUTTONS] = 41;
  old_window_color = BG_COLOR[COLOR_WINDOW];
 
+ AUTO_INDENT = 1;
  GNU_DOS_LEVEL = 1;
  int i;
-  //set defaults for Dir view//
+ for(i=0; i<100; i++) AUTO_INDENT_STR[i] = '\0';
+ //set defaults for Dir view//
  numVisDirs = SCREEN_H-9;
  firstVisDir = 0;
  selectedDir = -1;
