@@ -35,6 +35,8 @@
 #include <sys/ioctl.h>
 #include <stdlib.h>
 
+extern char *STARTUP_FILE_NAME;
+
 void drawScrollBar();
 int isKeyword(int pos, int start);
 
@@ -58,7 +60,7 @@ void sighandler(int signo)
 struct termios oldtio, curtio;
 struct sigaction sa;
 
-int main(int argc, char *argv[]) 
+int main(int argc, char **argv) 
 {
  NULL_DEV = fopen("/dev/null", "r");
  parseLineArgs(argc, argv);  
@@ -81,13 +83,14 @@ int main(int argc, char *argv[])
 	totalCharsInLine[i] = 0;
 	total_tabs = 0;
       } totalLines = 1;
-      //open_file_name = (char *)malloc(strlen(argv[1]));
-      if(strrchr(argv[1], '/'))
-	strcpy(open_file_name, argv[1]);
-      else {
+      //if(strrchr(argv[1], '/'))
+      if(strrchr(STARTUP_FILE_NAME, '/'))
+	strcpy(open_file_name, STARTUP_FILE_NAME);
+      else 
+      {
 	strcpy(open_file_name, getcwd(NULL, 0));
 	strcat(open_file_name, "/");
-	strcat(open_file_name, argv[1]);
+	strcat(open_file_name, STARTUP_FILE_NAME);
       }
       if(!openSaveFile(OPEN, NO)) {//failed to open file
 	NEW_FILE = 1; FILE_STATE = NEW;
@@ -543,7 +546,6 @@ do_up:
      }
      if(SELECTED) { SELECTED = 0; refreshView(); }
      refreshView();
-     //refreshBottomView();
      fflush(stdout);
      break;
    case(DOWN_KEY):
@@ -577,8 +579,7 @@ do_down:
 	sel_range_end.nchar = selectedChar;
 	refreshView();
      }
-      refreshView();
-     //refreshBottomView();
+     refreshView();
      if(SELECTED) { SELECTED = 0; refreshView(); }
      fflush(stdout);
      break;
@@ -690,6 +691,9 @@ do_del:
      { 
        if(GNU_DOS_LEVEL > 4)
        {//GNU key binding
+	 setScreenColors(FG_COLOR[COLOR_STATUS_BAR], BG_COLOR[COLOR_STATUS_BAR]);
+	 fprintf(stdout, "\e[%d;%dH", SCREEN_H, 0);
+	 fprintf(stdout, "[C-f] [C-e] [C-o] [C-h] [C-c] [C-s] [C-u] [C-g]");
 	 while(1)
 	 {
 	    ch = getKey();
@@ -702,6 +706,7 @@ do_del:
 	    else if(ch[0] == 'u') { editMenu_Undo(); break; }
 	    else if(ch[0] == 'g' && CTRL) { break; }
 	 }//end while
+	 refreshBottomView();
 	 break;
        }//end inner if
        else editMenu_Cut();
@@ -1306,6 +1311,22 @@ void insertEnter()
   int i;
   int pos = firstVisLine+selectedLine;
   setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+
+  if(AUTO_INDENT)
+  {
+    int m = 0;
+    for(i = 0; i < strlen(lines[pos]); i+=4)
+      if(lines[pos][i] == ' ' || lines[pos][i] == '\t')
+      { 
+	AUTO_INDENT_STR[m] = lines[pos][i]; 
+	AUTO_INDENT_STR[m+1] = lines[pos][i+1]; 
+	AUTO_INDENT_STR[m+2] = lines[pos][i+2]; 
+	AUTO_INDENT_STR[m+3] = lines[pos][i+3]; 
+	m+=4;
+      }
+      else break;
+    AUTO_INDENT_STR[m] = '\0';
+  }
   
   //if(RECORDING_UNDO_ACTION) finish_undo_action();
   if(!RECORDING_UNDO_ACTION) begin_undo_action(UNDO_ACTION_INSERT);
@@ -1324,7 +1345,13 @@ void insertEnter()
   else if(pos == totalLines-1) 
   {
     //totalLines++;
-    strcpy(lines[pos+1], lines[pos]+(selectedChar*4));
+    if(AUTO_INDENT)
+    {
+      strcpy(lines[pos+1], AUTO_INDENT_STR);
+      strcat(lines[pos+1], lines[pos]+(selectedChar*4));
+    }
+    else strcpy(lines[pos+1], lines[pos]+(selectedChar*4));
+    
     lines[pos][selectedChar*4] = '\0';
     totalCharsInLine[pos] = strlen(lines[pos])/4;
     totalCharsInLine[pos+1] = strlen(lines[pos+1])/4;
@@ -1411,12 +1438,28 @@ void insertEnter()
 	totalCharsInLine[pos+2] = strlen(lines[pos+2])/4;
 	pos++; if(pos+1 >= totalLines) break;
       }//end while
+      
+    if(AUTO_INDENT)
+    {
+      pos = firstVisLine+selectedLine;
+      char *tmp = (char *) malloc((MAX_CHARS_PER_LINE+TAB_CHARS)*4);
+      strcpy(tmp, lines[pos+1]);
+      strcpy(lines[pos+1], AUTO_INDENT_STR);
+      strcat(lines[pos+1], tmp);
+      free(tmp);
+    }
   } 
   else 
   {
       lines[pos][selectedChar*4] = '\0';
       totalCharsInLine[pos+1] = 0;
       lines[pos+1][0] = '\0';
+      if(AUTO_INDENT)
+      {
+	strcpy(lines[pos+1], AUTO_INDENT_STR);
+	totalCharsInLine[pos+1] = strlen(lines[pos+1])/4;
+	checkTabsInLine(pos+1);
+      }
       LINE_IS_LINKED[pos] = 0;
       totalLines++;
   }//end if #2
@@ -1438,7 +1481,7 @@ void insertTab()
   //insertChar('\t');
   insertChar(t);
   
-  selectedCharCarry += j-1;
+  //selectedCharCarry += j-1;
   refreshBottomView();
   return;
 }//end insertTab()
@@ -1481,22 +1524,108 @@ void insertChar(char *ch)
       }//end if(INSERT)
       if(selectedChar < strlen(lines[pos])/4) 
       { //if #3
-	if(!RECORDING_UNDO_ACTION) begin_undo_action(UNDO_ACTION_INSERT);
 	//there are chars to the right of cursor
-	lines[pos][strlen(lines[pos])+4] = '\0';
+	if(!RECORDING_UNDO_ACTION) begin_undo_action(UNDO_ACTION_INSERT);
+	char *tmp = (char *)malloc((MAX_CHARS_PER_LINE+TAB_CHARS)*4);
+	strcpy(tmp, lines[pos+1]);
+	char last_char[5];
+	strncpy(last_char, lines[pos]+(MAX_CHARS_PER_LINE*4)-4, 4);
+	last_char[5] = '\0';
+	
+	if(strlen(lines[pos])/4 > MAX_CHARS_PER_LINE)
+	  lines[pos][MAX_CHARS_PER_LINE*4] = '\0';
+	else
+	  lines[pos][strlen(lines[pos])+4] = '\0';
+	
 	for(i = strlen(lines[pos])+3; i >= selectedChar*4+4; i--)
 	  lines[pos][i] = lines[pos][i-4];
 	lines[pos][selectedChar*4] = ch[0];
 	lines[pos][selectedChar*4+1] = ch[1];
 	lines[pos][selectedChar*4+2] = ch[2];
 	lines[pos][selectedChar*4+3] = ch[3];
+	strcpy(lines[pos+1], tmp);
+	//strcpy(tmp, lines[pos+1]);
+	//checkTabsInLine(pos);
 
 	selectedChar++;
 	if(RECORDING_UNDO_ACTION) add_to_undo_action(ch);
+	//calculate character offset
+	selectedCharCarry = 0;
+	for(i = 0; i < selectedChar; i++)
+	  if(lines[firstVisLine+selectedLine][i*4] == '\t')
+	  { int j = TAB_CHARS-((i+selectedCharCarry)%TAB_CHARS); j=0?TAB_CHARS:j; selectedCharCarry+=(j-1); }
+	//////////////////////////////////////////
+	fprintf(stdout, "\e[%d;%dH", selectedLine+3, selectedChar+2+selectedCharCarry);
 	//THE LINE IS SPILLING OVER.. ADD LAST CHAR TO NEXT LINE
-	//remove bad tabs from the list first
-	//removeBadTabs();
-	//shiftTabsInLine(pos, selectedChar-1, 1);
+	if(strlen(lines[pos])/4 > MAX_CHARS_PER_LINE)
+	{
+	  int last_pos = pos;
+	  if(LINE_IS_LINKED[pos])
+	  {
+	    int j;
+	    char *tmp2 = (char *)malloc((MAX_CHARS_PER_LINE+TAB_CHARS)*4);
+	    while(LINE_IS_LINKED[pos])
+	    {
+	      j = MAX_CHARS_PER_LINE*4; //strlen(lines[pos]);
+	      strcpy(tmp, lines[pos+1]);
+	      lines[pos+1][0] = last_char[0];
+	      lines[pos+1][1] = last_char[1];
+	      lines[pos+1][2] = last_char[2];
+	      lines[pos+1][3] = last_char[3];
+	      strncpy(last_char, lines[pos]+(MAX_CHARS_PER_LINE*4)-4, 4);
+	      last_char[5] = '\0';
+	      lines[pos+1][4] = '\0';
+	      lines[pos][j] = '\0';
+	      strcpy(tmp2, lines[pos+2]);
+	      strcat(lines[pos+1], tmp);
+	      strcpy(lines[pos+2], tmp2);
+	      checkTabsInLine(pos+1);
+	      pos++;
+	    }
+	    //pos--;
+	    //if last line is long, make a new line
+	    if(strlen(lines[pos])/4 > MAX_CHARS_PER_LINE)
+	    {
+	      totalLines++;
+	      for(i = totalLines; i > pos+1; i--)
+	      {
+		strcpy(lines[i], lines[i-1]);
+		LINE_IS_LINKED[i] = LINE_IS_LINKED[i-1];
+		totalCharsInLine[i] = totalCharsInLine[i-1];
+	      }
+	      j = strlen(lines[pos]);
+	      lines[pos+1][0] = lines[pos][j-4];
+	      lines[pos+1][1] = lines[pos][j-3];
+	      lines[pos+1][2] = lines[pos][j-2];
+	      lines[pos+1][3] = lines[pos][j-1];
+	      lines[pos+1][4] = '\0';
+	      lines[pos][j-4] = '\0';
+	      checkTabsInLine(pos+1);
+	    }
+	  }
+	  //line is not linked
+	  else
+	  {
+	      totalLines++;
+	      for(i = totalLines; i > pos+1; i--)
+	      {
+		strcpy(lines[i], lines[i-1]);
+		LINE_IS_LINKED[i] = LINE_IS_LINKED[i-1];
+		totalCharsInLine[i] = totalCharsInLine[i-1];
+	      }
+	      int j = strlen(lines[pos]);
+	      lines[pos+1][0] = lines[pos][j-4];
+	      lines[pos+1][1] = lines[pos][j-3];
+	      lines[pos+1][2] = lines[pos][j-2];
+	      lines[pos+1][3] = lines[pos][j-1];
+	      lines[pos+1][4] = '\0';
+	      lines[pos][j-4] = '\0';
+	      checkTabsInLine(pos+1);
+	  }
+	  pos = last_pos;
+	}
+	free(tmp);
+	//free(last_char);
 	checkTabsInLine(pos);
 	refreshView();
 	//refreshSelectedLine();
@@ -1511,21 +1640,9 @@ void insertChar(char *ch)
 	lines[pos][selectedChar*4+3] = ch[3];
 	lines[pos][selectedChar*4+4] = '\0';
 	selectedChar++;
-	//v++;
-	//fprintf(stderr, "%d\n", v);
-	//totalCharsInLine[pos]++;
 	checkTabsInLine(pos);
-	//v++;
-	//fprintf(stderr, "%d\n", v);
-	//putchar(ch); //printf("\n\n%d\n", selectedChar);
-	//sleep(1);
 	refreshSelectedLine();
-	//v++;
-	//fprintf(stderr, "%d\n", v);
 	if(RECORDING_UNDO_ACTION) add_to_undo_action(ch);
-	//v++;
-	//fprintf(stderr, "%d\n", v);
-	//refreshBottomView();
       }//end if #3
     } 
     else 
@@ -1570,14 +1687,14 @@ void insertChar(char *ch)
 	c[1] = lines[pos][MAX_CHARS_PER_LINE*4-3];
 	c[2] = lines[pos][MAX_CHARS_PER_LINE*4-2];
 	c[3] = lines[pos][MAX_CHARS_PER_LINE*4-1];
-	c[4] = 0;
+	c[4] = '\0';
 	  lines[pos][MAX_CHARS_PER_LINE*4-4] = ch[0];
 	  lines[pos][MAX_CHARS_PER_LINE*4-3] = ch[1];
 	  lines[pos][MAX_CHARS_PER_LINE*4-2] = ch[2];
 	  lines[pos][MAX_CHARS_PER_LINE*4-1] = ch[3];
 	lines[pos][MAX_CHARS_PER_LINE*4] = '\0';
-	totalCharsInLine[pos] = strlen(lines[pos]);
-	char *tmp = (char *) malloc(MAX_CHARS_PER_LINE*4);
+	totalCharsInLine[pos] = strlen(lines[pos])/4;
+	char *tmp = (char *) malloc((MAX_CHARS_PER_LINE+TAB_CHARS)*4);
 	while(LINE_IS_LINKED[i-1]) 
 	{
 	  strcpy(tmp, lines[i]);
@@ -1594,7 +1711,7 @@ void insertChar(char *ch)
 	  c[2] = lines[pos][MAX_CHARS_PER_LINE*4-2];
 	  c[3] = lines[pos][MAX_CHARS_PER_LINE*4-1];
 	  lines[i][MAX_CHARS_PER_LINE*4-4] = '\0';
-	  totalCharsInLine[i] = strlen(lines[i]);
+	  totalCharsInLine[i] = strlen(lines[i])/4;
 	  //shiftTabsInLine(i, 0, 1);
 	  i++;
 	}//end while
@@ -1690,7 +1807,7 @@ void refreshSelectedLine()
 	    else setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	    int j;
 	    if(lines[pos][i] == '\t')
-	      { j = TAB_CHARS-((i+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
+	      { j = TAB_CHARS-((i/4+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
 	      //for(j = 0; j < TAB_CHARS-((i+carry)%TAB_CHARS); j++) putchar(' ');
 	    //else putchar(lines[pos][i]);
 	    else putuchar(pos, i);
@@ -1812,7 +1929,65 @@ void refreshSelectedLineInColor(int pos)
 {
   int i;
   i = pos;
+
+  //check for multi-line HTML comments
+  if(HIGHLIGHT_MODE == HTML_MODE)
+  {
+   for(i = pos-((pos>0)?1:0); i >= 0; i--)
+    if(strstr(lines[i], "-   -   >")) break;
+    else if(strstr(lines[i], "<   !   -   -"))
+    {
+	setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
+	int j, carry = 0;
+	for(i = 0; i < strlen(lines[pos]); i+=4)
+	  if(lines[pos][i] == '\t')
+	    { j = TAB_CHARS-((i/4+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
+	    //for(j = 0; j < TAB_CHARS-((i+carry)%TAB_CHARS); j++) putchar(' ');
+	  //else putchar(lines[pos][i]);
+	  else putuchar(pos, i);
+	  
+	return;
+    }
+  }
+
+  //check for multi-line PASCAL comments
+  if(HIGHLIGHT_MODE == PASCAL_MODE)
+  {
+   for(i = pos-((pos>0)?1:0); i >= 0; i--)
+    if(strstr(lines[i], "*   }")) break;
+    else if(strstr(lines[i], "{   *"))
+    {
+	setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
+	int j, carry = 0;
+	for(i = 0; i < strlen(lines[pos]); i+=4)
+	  if(lines[pos][i] == '\t')
+	    { j = TAB_CHARS-((i/4+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
+	    //for(j = 0; j < TAB_CHARS-((i+carry)%TAB_CHARS); j++) putchar(' ');
+	  //else putchar(lines[pos][i]);
+	  else putuchar(pos, i);
+	  
+	return;
+    }
+  }
   
+  //check for FORTRAN 77 comments
+  if(HIGHLIGHT_MODE == F77_MODE)
+  {
+    if(lines[i][0] == 'c' || lines[i][0] == 'C' || lines[i][0] == 'd'
+       || lines[i][0] == 'D' || lines[i][0] == '*' || lines[i][0] == '!')
+    {
+	setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
+	int j, carry = 0;
+	for(i = 0; i < strlen(lines[pos]); i+=4)
+	  if(lines[pos][i] == '\t')
+	    { j = TAB_CHARS-((i/4+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
+	    //for(j = 0; j < TAB_CHARS-((i+carry)%TAB_CHARS); j++) putchar(' ');
+	  //else putchar(lines[pos][i]);
+	  else putuchar(pos, i);
+	return;
+    }
+  }
+
   //check for python multi-line comments
   if(HIGHLIGHT_MODE == PYTHON_MODE)
   {
@@ -1823,7 +1998,7 @@ void refreshSelectedLineInColor(int pos)
 	int j, carry = 0;
 	for(i = 0; i < strlen(lines[pos]); i+=4)
 	  if(lines[pos][i] == '\t')
-	    { j = TAB_CHARS-((i+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
+	    { j = TAB_CHARS-((i/4+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
 	    //for(j = 0; j < TAB_CHARS-((i+carry)%TAB_CHARS); j++) putchar(' ');
 	  //else putchar(lines[pos][i]);
 	  else putuchar(pos, i);
@@ -1833,13 +2008,17 @@ void refreshSelectedLineInColor(int pos)
   }
   
   //check for texi comments
-  if(HIGHLIGHT_MODE == TEXI_MODE && lines[i][0] == '@' && lines[i][4] == 'c')
+//  if(HIGHLIGHT_MODE == TEXI_MODE && lines[i][0] == '@' && lines[i][4] == 'c'
+//     && lines[i][8] == ' ')
+  if(HIGHLIGHT_MODE == TEXI_MODE &&
+     strstr(lines[i], "@   c   o   m   m   e   n   t")
+     || (strstr(lines[i], "@   c    ") == lines[i]))
   {
 	setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
 	int k, l, carry = 0;
 	for(k = 0; k < strlen(lines[i]); k+=4)
 	  if(lines[pos][k] == '\t')
-	    { l = TAB_CHARS-((k+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	    { l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
 	  else putuchar(i, k);
 	//printf("%s", lines[i]);
 	return;
@@ -1847,10 +2026,12 @@ void refreshSelectedLineInColor(int pos)
   //check first to see if this is part of a multi-line comment.
   //if so, it will save us the pain of parsing the line.
    i = pos;
-   if(HIGHLIGHT_MODE == C_MODE || HIGHLIGHT_MODE == CPP_MODE) 
+   if(HIGHLIGHT_MODE == C_MODE || HIGHLIGHT_MODE == CPP_MODE
+      || HIGHLIGHT_MODE == JAVASCRIPT_MODE) 
    {
    while(i && LINE_IS_LINKED[i-1]) i--;
-   if(LINE_IS_LINKED[i] && i != pos) {//see if it is a commented line
+   if(LINE_IS_LINKED[i] && i != pos) 
+   {//see if it is a commented line
     int j; 
     for(j = strlen(lines[i])-1; j > 0; j-=4)
       if(lines[i][j-4] == '/' && (lines[i][j] == '*' || lines[i][j] == '/')) 
@@ -1859,7 +2040,7 @@ void refreshSelectedLineInColor(int pos)
 	int k, l, carry = 0;
 	for(k = 0; k < strlen(lines[pos]); k+=4)
 	  if(lines[pos][k] == '\t')
-	    { l = TAB_CHARS-((k+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	    { l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
 	  else putuchar(pos, k);
 	//printf("%s", lines[pos]);
 	return;
@@ -1874,7 +2055,7 @@ void refreshSelectedLineInColor(int pos)
 	int j, carry = 0;
 	for(i = 0; i < strlen(lines[pos]); i+=4)
 	  if(lines[pos][i] == '\t')
-	    { j = TAB_CHARS-((i+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
+	    { j = TAB_CHARS-((i/4+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
 	    //for(j = 0; j < TAB_CHARS-((i+carry)%TAB_CHARS); j++) putchar(' ');
 	  //else putchar(lines[pos][i]);
 	  else putuchar(pos, i);
@@ -1882,12 +2063,18 @@ void refreshSelectedLineInColor(int pos)
 	return;
     }
   }//finished checking for C/C++ comments
-  
+
+  char STRING_STARTED = 0;//bool to indicate if we are inside a string
   //so the line is not part of a comment.. parse it.
   setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   for(i = 0; i < strlen(lines[pos]); i+=4)
     if(lines[pos][i] == ';') 
     { 
+      if(STRING_STARTED)
+      { 
+	putuchar(pos, i);
+	continue; 
+      }
       //Check for assembly comments, as they start with a semi-colon
       if(HIGHLIGHT_MODE == ASM_MODE)
       {
@@ -1895,7 +2082,7 @@ void refreshSelectedLineInColor(int pos)
 	int k, l, carry = 0;
 	for(k = i; k < strlen(lines[pos]); k+=4)
 	  if(lines[pos][k] == '\t')
-	    { l = TAB_CHARS-((k+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	    { l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
 	  else putuchar(pos, k);
 	//printf("%s", lines[pos]);
 	return;
@@ -1909,6 +2096,23 @@ void refreshSelectedLineInColor(int pos)
 	    || lines[pos][i] == ':' || lines[pos][i] == '[' 
 	    || lines[pos][i] == ']') 
     { 
+      if(STRING_STARTED)
+      { 
+	putuchar(pos, i);
+	continue; 
+      }
+      //Check for PASCAL comments, as they start with a curly brace
+      if(HIGHLIGHT_MODE == PASCAL_MODE && lines[pos][i] == '{')
+      {
+	setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
+	int k, l, carry = 0;
+	for(k = i; k < strlen(lines[pos]); k+=4)
+	  if(lines[pos][k] == '\t')
+	    { l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	  else putuchar(pos, k);
+	return;
+      }
+      //if not in PASCAL_MODE, just output curly brace
       setScreenColors(COLOR_HBRACES, BG_COLOR[COLOR_WINDOW]);
       //putchar(lines[pos][i]); 
       putuchar(pos, i);
@@ -1916,24 +2120,59 @@ void refreshSelectedLineInColor(int pos)
     }
     else if(lines[pos][i] == '"' || lines[pos][i] == '\'')
     { 
-      setScreenColors(COLOR_HSTRING, BG_COLOR[COLOR_WINDOW]);
+      //Check for basic comments, as they start with a single quote
+      if(HIGHLIGHT_MODE == BASIC_MODE && lines[pos][i] == '\'')
+      {
+	setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
+	int k, l, carry = 0;
+	for(k = i; k < strlen(lines[pos]); k+=4)
+	  if(lines[pos][k] == '\t')
+	    { l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	  else putuchar(pos, k);
+	//printf("%s", lines[pos]);
+	return;
+      }
+      //if not in BASIC_MODE, just output the single quote
+      if(HIGHLIGHT_MODE != TEXI_MODE)
+	setScreenColors(COLOR_HSTRING, BG_COLOR[COLOR_WINDOW]);
       //putchar(lines[pos][i]); 
       putuchar(pos, i);
-      setScreenColors(COLOR_HPARAMETERS, BG_COLOR[COLOR_WINDOW]); continue; 
+      if(STRING_STARTED)
+      {//string is finished, switch color
+	STRING_STARTED = 0;
+	setScreenColors(COLOR_HPARAMETERS, BG_COLOR[COLOR_WINDOW]); continue; 
+	printf("\e[1m"); //set bold font
+      }
+      else 
+      {
+	STRING_STARTED = 1;
+	printf("\e[22m"); //remove bold font
+      }
     }
     else if(lines[pos][i] != ' ' && lines[pos][i] != '\t') 
     {
+      if(STRING_STARTED)
+      { 
+	putuchar(pos, i);
+	continue; 
+      }
       if(lines[pos][i] == '/' && (lines[pos][i+4] == '/' || lines[pos][i+4] == '*')) 
       {
-	if(HIGHLIGHT_MODE != C_MODE && HIGHLIGHT_MODE != CPP_MODE)
+	if(HIGHLIGHT_MODE != C_MODE && HIGHLIGHT_MODE != CPP_MODE
+	   && HIGHLIGHT_MODE != JAVASCRIPT_MODE)
 	  { 
-	    //putchar(lines[pos][i]); 
 	    putuchar(pos, i);
 	    continue; 
 	  }
 	setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
-	putuchar(pos, i); putuchar(pos, i+4); i+4;
-	continue;
+	//putuchar(pos, i); putuchar(pos, i+4); i+4;
+	//continue;
+	int k, l, carry = 0;
+	for(k = i; k < strlen(lines[pos]); k+=4)
+	if(lines[pos][k] == '\t')
+	{ l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	else putuchar(pos, k);
+	return;
 	//printf("%s", lines[pos]+i); break;
       } 
       else if(lines[pos][i] == '#') 
@@ -1954,23 +2193,64 @@ void refreshSelectedLineInColor(int pos)
 	  putuchar(pos, i); continue;
 	  //printf("%s", lines[pos]+i); break;
 	}
+	//We will print out a C/C++ preprocessor directive.
+	//But sometimes programmers write comments to the right
+	//side of these, so check if there is a comment in the line.
+	int m;
+	char *comment = strstr(lines[pos], "/   /   ");
+	if(comment == NULL)
+	  comment = strstr(lines[pos], "/   *   ");
+	if(comment == NULL)
+	  m = strlen(lines[pos]);
+	else m = comment-lines[pos];
+
+	//print the preprocessor directive first
 	int k, l, carry = 0;
+	for(k = i; k < m; k+=4)
+	    if(lines[pos][k] == '\t')
+	    { l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	    else putuchar(pos, k);
+	//then print the comment, if any
+	setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
+	i = k;
 	for(k = i; k < strlen(lines[pos]); k+=4)
 	    if(lines[pos][k] == '\t')
-	    { l = TAB_CHARS-((k+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	    { l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
 	    else putuchar(pos, k);
 	return;
       } 
       else 
       {
+	if(STRING_STARTED)
+	{ 
+	    putuchar(pos, i);
+	    continue; 
+	}
 	int j;
 	if((j = isKeyword(pos, i))) 
 	{
+	  //Check for basic comments, as they start with REM
+	  if(HIGHLIGHT_MODE == BASIC_MODE 
+	     && (strcasestr(lines[pos], "R   E   M")))// != (char *)NULL))
+	  {
+	    setScreenColors(COLOR_HCOMMENT, BG_COLOR[COLOR_WINDOW]);
+	    int k, l, carry = 0;
+	    for(k = i; k < strlen(lines[pos]); k+=4)
+	      if(lines[pos][k] == '\t')
+	      { l = TAB_CHARS-((k/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	      else putuchar(pos, k);
+	    //printf("%s", lines[pos]);
+	    return;
+	  }
+	  //if not in BASIC_MODE, just output the keyword
 	  setScreenColors(COLOR_HKEYWORD, BG_COLOR[COLOR_WINDOW]);
 	  int k;
 	  for(k = 0; k < j; k++) //putchar(lines[pos][i+k]);
-	    putuchar(pos, i);
-	  i += k-1;
+	  {
+	    putuchar(pos, i); i += 4;
+	  }
+	  i -= 4;
+	  //i += k-1;
 	} 
 	else 
 	{
@@ -1984,12 +2264,13 @@ void refreshSelectedLineInColor(int pos)
     {
       int j, carry = 0;
       if(lines[pos][i] == '\t')
-      { j = TAB_CHARS-((i+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
+      { j = TAB_CHARS-((i/4+carry)%TAB_CHARS); j=0?TAB_CHARS:j; carry+=(j-1); printf("%*s", j, " "); }
 	  //for(j = 0; j < TAB_CHARS-((i+carry)%TAB_CHARS); j++) putchar(' ');
       //else putchar(lines[pos][i]);
       else putuchar(pos, i);
       //putchar(lines[pos][i]);
     }
+    fflush(stdout);
  /////////////////////////////////////////////////////
  /////////////////////////////////////////////////////
  /////////////////////////////////////////////////////
@@ -2001,18 +2282,87 @@ void refreshSelectedLineInColor(int pos)
 int isKeyword(int pos, int start) 
 {
   int i;
+  int result = 0;
   for(i = 0; i < total_keywords; i++)
-    if((strstr(lines[pos]+start, keyword[i]))-(lines[pos]+start) == 0) 
+  {
+    if(HIGHLIGHT_MODE == ASM_MODE || HIGHLIGHT_MODE == BASIC_MODE)
+    {
+      int j;
+      //parse the keyword letter-by-letter. In this case, the
+      //keywords are saved as CAPITALS, so check for both capital
+      //and small versions of the keyword.
+      for(j = 0; j < strlen(keyword[i]); j++)
+	if(lines[pos][start+j*4] == keyword[i][j]
+	   || lines[pos][start+j*4] == (keyword[i][j])+32) continue;
+	else { result = -1; break; }
+      if(result == -1) result = 0;
+      else //make sure this is not part of another word
+	if(((lines[pos][start+j*4] > 'z' 
+	   || lines[pos][start+j*4] < 'a' && lines[pos][start+j*4] > 'Z'
+	   || lines[pos][start+j*4] < 'A') && lines[pos][start+j*4] != '_')
+	  &&
+	((lines[pos][start-4] > 'z' 
+	   || lines[pos][start-4] < 'a' && lines[pos][start-4] > 'Z'
+	   || lines[pos][start-4] < 'A') && lines[pos][start-4] != '_'))
+	return strlen(keyword[i]);
+    }
+    else if(HIGHLIGHT_MODE == F77_MODE || HIGHLIGHT_MODE == HTML_MODE
+	    || HIGHLIGHT_MODE == PASCAL_MODE)
+    {
+      int j;
+      //parse the keyword letter-by-letter. In this case, the
+      //keywords are saved as SMALL LETTERS, so check for both capital
+      //and small versions of the keyword.
+      for(j = 0; j < strlen(keyword[i]); j++)
+	if(lines[pos][start+j*4] == keyword[i][j]
+	   || lines[pos][start+j*4] == (keyword[i][j])-32) continue;
+	else { result = -1; break; }
+      if(result == -1) result = 0;
+      else //make sure this is not part of another word
+	if(((lines[pos][start+j*4] > 'z' 
+	   || lines[pos][start+j*4] < 'a' && lines[pos][start+j*4] > 'Z'
+	   || lines[pos][start+j*4] < 'A') && lines[pos][start+j*4] != '_')
+	  &&
+	((lines[pos][start-4] > 'z' 
+	   || lines[pos][start-4] < 'a' && lines[pos][start-4] > 'Z'
+	   || lines[pos][start-4] < 'A') && lines[pos][start-4] != '_'))
+	return strlen(keyword[i]);
+    }
+    else
+    {
+      int j;
+      //parse the keyword letter-by-letter. In this case, the
+      //keywords are saved as SMALL LETTERS, and they should be
+      //interpreted strictly in this form. kewords in C/C++,
+      //JavaScript, Perl, and Python should all be small case.
+      for(j = 0; j < strlen(keyword[i]); j++)
+	if(lines[pos][start+j*4] == keyword[i][j]) continue;
+	else { result = -1; break; }
+      if(result == -1) result = 0;
+      else //make sure this is not part of another word
+	if(((lines[pos][start+j*4] > 'z' 
+	   || lines[pos][start+j*4] < 'a' && lines[pos][start+j*4] > 'Z'
+	   || lines[pos][start+j*4] < 'A') && lines[pos][start+j*4] != '_')
+	  &&
+	((lines[pos][start-4] > 'z' 
+	   || lines[pos][start-4] < 'a' && lines[pos][start-4] > 'Z'
+	   || lines[pos][start-4] < 'A') && lines[pos][start-4] != '_'))
+	return strlen(keyword[i]);
+    }
+  }
+    /*if((strstr(lines[pos]+start, keyword[i]))-(lines[pos]+start) == 0) 
     {
       char c = lines[pos][start+strlen(keyword[i])];
       if((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z')) return 0;
       else return strlen(keyword[i]);
-    }
+    }*/
   return 0;
 }
 
 void refreshView() 
 {
+  //turn the cursor off
+  printf("\e[?25l");
   int i;
   if(totalLines-firstVisLine < totalVisLines &&
      totalLines > totalVisLines) 
@@ -2021,7 +2371,7 @@ void refreshView()
     firstVisLine = totalLines-totalVisLines;
     selectedLine += i-firstVisLine;
   }
-  checkAllTabs();
+  //checkAllTabs();
   setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   if(WRAP_LINES)
   {//if #1
@@ -2063,7 +2413,7 @@ void refreshView()
 	      else setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	      int k;
 	      if(lines[i][j] == '\t')
-	      { k = TAB_CHARS-((j+carry)%TAB_CHARS); k=0?TAB_CHARS:k; carry+=(k-1); printf("%*s", k, " "); }
+	      { k = TAB_CHARS-((j/4+carry)%TAB_CHARS); k=0?TAB_CHARS:k; carry+=(k-1); printf("%*s", k, " "); }
 		//for(k = 0; k < TAB_CHARS-((j+carry)%TAB_CHARS); k++) putchar(' ');
 	      //else putchar(lines[i][j]);
 	      else putuchar(i, j);
@@ -2096,7 +2446,7 @@ void refreshView()
 	  else
 	    for(j = 0; j < strlen(lines[i]); j+=4)
 	      if(lines[i][j] == '\t')
-	      { k = TAB_CHARS-((j+carry)%TAB_CHARS); k=0?TAB_CHARS:k; carry+=(k-1); printf("%*s", k, " "); }
+	      { k = TAB_CHARS-((j/4+carry)%TAB_CHARS); k=0?TAB_CHARS:k; carry+=(k-1); printf("%*s", k, " "); }
 		//for(k = 0; k < TAB_CHARS-((j+carry)%TAB_CHARS); k++) putchar(' ');
 	      //else putchar(lines[i][j]);
 	      else putuchar(i, j);
@@ -2148,7 +2498,7 @@ void refreshView()
 	      else setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	      int l;
 	      if(lines[i][j] == '\t')
-	      { l = TAB_CHARS-((j+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
+	      { l = TAB_CHARS-((j/4+carry)%TAB_CHARS); l=0?TAB_CHARS:l; carry+=(l-1); printf("%*s", l, " "); }
 		//for(l = 0; l < TAB_CHARS-((j+carry)%TAB_CHARS); l++) putchar(' ');
 	      //else putchar(lines[firstVisLine+i][j]);
 	      else putuchar(firstVisLine+i, j);
@@ -2176,7 +2526,7 @@ void refreshView()
 	  else 
 	    for(j = 0; j < strlen(lines[firstVisLine+i]); j+=4)
 	      if(lines[firstVisLine+i][j] == '\t')
-	      { k = TAB_CHARS-((j+carry)%TAB_CHARS); k=0?TAB_CHARS:k; carry+=(k-1); printf("%*s", k, " "); }
+	      { k = TAB_CHARS-((j/4+carry)%TAB_CHARS); k=0?TAB_CHARS:k; carry+=(k-1); printf("%*s", k, " "); }
 		//for(k = 0; k < TAB_CHARS-((j+carry)%TAB_CHARS); k++) putchar(' ');
 	      //else putchar(lines[firstVisLine+i][j]);
 	      else putuchar(firstVisLine+i, j);
@@ -2192,6 +2542,8 @@ void refreshView()
   drawBox(2, 1, SCREEN_H-1, SCREEN_W, documentTitle, NO);	//draw main window
   drawScrollBar();
   refreshBottomView();
+  //turn the cursor on
+  printf("\e[?25h");
   fflush(stdout);
 }//end refreshView()
 
