@@ -71,14 +71,26 @@ void showFileMenu(int visible)
       ch = getKey();
       switch(ch[0]) 
       {
+	case('g'):
+	  if(GNU_DOS_LEVEL < 3) break;
+	  if(!CTRL) break;
+	  goto do_esc;
 	case(ESC_KEY):
+	  if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
 	  fflush(stdout);
 	  endme = 1;
 	  break;
+	case('p'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_up;
 	case(UP_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  fprintf(stdout, "\e[%d;3H%s", fSelect+3, fileMenu[fSelect]);	//clear last selection
@@ -90,7 +102,13 @@ void showFileMenu(int visible)
 	  fprintf(stdout, "\e[%d;18H", fSelect+3);
 	  fflush(stdout);
 	  break;
+	case('n'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_down;
 	case(DOWN_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  fprintf(stdout, "\e[%d;3H%s", fSelect+3, fileMenu[fSelect]);	//clear last selection
@@ -103,15 +121,21 @@ void showFileMenu(int visible)
 	  fflush(stdout);
 	  break;
 	case('f'):	//hide the file menu and return control to main program
-	  if(!ALT) break;
-	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
-	  //setScreenColors(WHITE, BGBLUE);
-	  refreshView();
-	  return;
+	  if(ALT)
+	  {
+	    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	    //setScreenColors(WHITE, BGBLUE);
+	    refreshView();
+	    return;
+	  }
+	  else if(CTRL)
+	   if(GNU_DOS_LEVEL > 1) goto do_right;
 	  break;
 	case('e'):	//navigate to Mino menu
 	  if(!ALT) break;
 	case(RIGHT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_right:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
@@ -120,7 +144,14 @@ void showFileMenu(int visible)
 	  break;
 	case('h'):	//navigate to Help menu
 	  if(!ALT) break;
+	  goto do_left;
+	case('b'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_left;
 	case(LEFT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_left:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
@@ -216,13 +247,25 @@ void showEditMenu(int visible)
       ch = getKey();
       switch(ch[0]) 
       {
+	case('g'):
+	  if(GNU_DOS_LEVEL < 3) break;
+	  if(!CTRL) break;
+	  goto do_esc;
 	case(ESC_KEY):
+	  if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
 	  endme = 1;
 	  break;
+	case('p'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_up;
 	case(UP_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  fprintf(stdout, "\e[%d;9H%s", eSelect+3, editMenu[eSelect]);	//clear last selection
@@ -234,7 +277,13 @@ void showEditMenu(int visible)
 	  fprintf(stdout, "\e[%d;29H", eSelect+3);
 	  fflush(stdout);
 	  break;
+	case('n'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_down;
 	case(DOWN_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  fprintf(stdout, "\e[%d;9H%s", eSelect+3, editMenu[eSelect]);	//clear last selection
@@ -253,9 +302,17 @@ void showEditMenu(int visible)
 	  refreshView();
 	  return;
 	  break;
+	case('b'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_left;
 	case('f'):	//navigate to File menu
-	  if(!ALT) break;
+	 if(CTRL)
+	   if(GNU_DOS_LEVEL > 1) goto do_right;
+	 if(!ALT) break;
 	case(LEFT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_left:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
@@ -272,7 +329,10 @@ void showEditMenu(int visible)
 	  break;
 	case('o'):	//navigate to Options menu
 	  if(!ALT) break;
+	 goto do_right;
 	case(RIGHT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_right:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
@@ -326,7 +386,7 @@ void showOptionsMenu(int visible)
   {	//show the file menu
     //activeWindow = HELP_MENU;
     setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
-    drawBox(2, 14, 6, 31, NULL, YES);
+    drawBox(2, 14, 7, 31, NULL, YES);
     setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
     //setScreenColors(BLUE, BGWHITE);
     fprintf(stdout, "\e[3;15H%s", optionsMenu[0]);
@@ -338,14 +398,27 @@ void showOptionsMenu(int visible)
     while(!endme) 
     {				//wait for user input
       ch = getKey();
-      switch(ch[0]) {
+      switch(ch[0]) 
+      {
+	case('g'):
+	  if(GNU_DOS_LEVEL < 3) break;
+	  if(!CTRL) break;
+	  goto do_esc;
 	case(ESC_KEY):
+	  if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
 	  endme = 1;
 	  break;
+	case('p'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_up;
 	case(UP_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  fprintf(stdout, "\e[%d;15H%s", oSelect+3, optionsMenu[oSelect]);	//clear last selection
@@ -357,7 +430,13 @@ void showOptionsMenu(int visible)
 	  fprintf(stdout, "\e[%d;30H", oSelect+3);
 	  fflush(stdout);
 	  break;
+	case('n'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_down;
 	case(DOWN_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  fprintf(stdout, "\e[%d;15H%s", oSelect+3, optionsMenu[oSelect]);	//clear last selection
@@ -378,7 +457,10 @@ void showOptionsMenu(int visible)
 	  break;
 	case('h'):	//navigate to Help menu
 	  if(!ALT) break;
+	  goto do_right;
 	case(RIGHT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_right:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
@@ -386,6 +468,7 @@ void showOptionsMenu(int visible)
 	  endme = 1;
 	  break;
 	case('f'):	//navigate to File menu
+	  if(CTRL && GNU_DOS_LEVEL > 1) goto do_right;
 	  if(!ALT) break;
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
@@ -393,9 +476,16 @@ void showOptionsMenu(int visible)
 	  showFileMenu(YES);
 	  endme = 1;
 	  break;
-	case('e'):	//navigate to Mino menu
+	case('e'):	//navigate to Edit menu
 	  if(!ALT) break;
+	  goto do_left;
+	case('b'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_left;
 	case(LEFT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_left:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
@@ -407,11 +497,24 @@ void showOptionsMenu(int visible)
 	  {			//selected 'Change colors'
 	    optionsMenu_Change_Colors();
 	  }
-	  if(oSelect == 1) 
+	  else if(oSelect == 1) 
 	  {			//selected 'Tab spaces'
 	    optionsMenu_Tab_Spaces();
 	  }
-	  if(oSelect == 2) 
+	  else if(oSelect == 2) 
+	  {			//selected 'Autoindent'
+	    if(AUTO_INDENT)
+	    {
+	      AUTO_INDENT = 0;
+	      optionsMenu[2][14] = ' ';
+	    }
+	    else
+	    {
+	      AUTO_INDENT = 1;
+	      optionsMenu[2][14] = '*';
+	    }
+	  }
+	  else if(oSelect == 3) 
 	  {			//selected 'Reset config'
 	    optionsMenu_Reset_Config();
 	  }
@@ -464,14 +567,27 @@ void showHelpMenu(int visible)
     while(!endme) 
     {				//wait for user input
       ch = getKey();
-      switch(ch[0]) {
+      switch(ch[0]) 
+      {
+	case('g'):
+	  if(GNU_DOS_LEVEL < 3) break;
+	  if(!CTRL) break;
+	  goto do_esc;
 	case(ESC_KEY):
+	  if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
 	  endme = 1;
 	  break;
+	case('p'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_up;
 	case(UP_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  fprintf(stdout, "\e[%d;24H%s", hSelect+3, helpMenu[hSelect]);	//clear last selection
@@ -483,7 +599,13 @@ void showHelpMenu(int visible)
 	  fprintf(stdout, "\e[%d;39H", hSelect+3);
 	  fflush(stdout);
 	  break;
+	case('n'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_down;
 	case(DOWN_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  fprintf(stdout, "\e[%d;24H%s", hSelect+3, helpMenu[hSelect]);	//clear last selection
@@ -503,8 +625,12 @@ void showHelpMenu(int visible)
 	  return;
 	  break;
 	case('f'):	//navigate to File menu
-	  if(!ALT) break;
+	 if(CTRL && GNU_DOS_LEVEL > 1) goto do_right;
+	 if(!ALT) break;
+	 goto do_right;
 	case(RIGHT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_right:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
@@ -520,8 +646,15 @@ void showHelpMenu(int visible)
 	  endme = 1;
 	  break;
 	case('o'):	//navigate to Options menu
-	  if(!ALT) break;
+	 if(!ALT) break;
+	 goto do_left;
+	case('b'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_left;
 	case(LEFT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_left:
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //setScreenColors(WHITE, BGBLUE);
 	  refreshView();
@@ -665,19 +798,39 @@ void showKeybindings()
   }
   
 readMore:
-  while(1) {
+  while(1) 
+  {
     ch = getKey();
-    switch(ch[0]) {
+    switch(ch[0]) 
+    {
+      case('g'):
+	if(GNU_DOS_LEVEL < 3) break;
+	if(!CTRL) break;
+	goto do_esc;
+      case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
       case(ENTER_KEY):
       case(SPACE_KEY):
-      case(ESC_KEY):
 	goto end;
 	break;
+      case('p'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_up;
       case(UP_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	if(firstVisLine == 0) break;	//can't go up--first line already
 	firstVisLine--;
 	break;
+      case('n'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_down;
       case(DOWN_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	if(!moreLines) break;	//reached last line
 	firstVisLine++;
 	break;
@@ -802,19 +955,39 @@ void showReadMe()
   }
   
 readMore:
-  while(1) {
+  while(1) 
+  {
     ch = getKey();
-    switch(ch[0]) {
+    switch(ch[0]) 
+    {
+      case('g'):
+	if(GNU_DOS_LEVEL < 3) break;
+	if(!CTRL) break;
+	goto do_esc;
+      case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
       case(ENTER_KEY):
       case(SPACE_KEY):
-      case(ESC_KEY):
 	goto end;
 	break;
+      case('p'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_up;
       case(UP_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	if(firstVisLine == 0) break;	//can't go up--first line already
 	firstVisLine--;
 	break;
+      case('n'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_down;
       case(DOWN_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	if(!moreLines) break;	//reached last line
 	firstVisLine++;
 	break;
