@@ -214,14 +214,24 @@ int openSaveFile(OPEN_SAVE openSave, int showDialog)
 	ch = getKey();
 	switch(ch[0]) 
 	{
+	  case('a'):
+	    if(GNU_DOS_LEVEL > 2 && CTRL) goto do_home;
+	    goto do_enter_char; break;
 	  case(HOME_KEY):
+	    if(GNU_DOS_LEVEL > 2) break;
+do_home:
 	    if(sel == 1) 
 	    {
 	      selChar = 0;
 	      fprintf(stdout, "\e[%d;%dH", h-2, y+selChar+7);
 	      fflush(stdout);
 	    } break;
+	  case('e'):
+	    if(GNU_DOS_LEVEL > 2 && CTRL) goto do_end;
+	    goto do_enter_char; break;
 	  case(END_KEY):
+	    if(GNU_DOS_LEVEL > 2) break;
+do_end:
 	    if(sel == 1) 
 	    {
 	      selChar = strlen(inputName);
@@ -229,7 +239,12 @@ int openSaveFile(OPEN_SAVE openSave, int showDialog)
 	      fprintf(stdout, "\e[%d;%dH", h-2, y+selChar+7);
 	      fflush(stdout);
 	    } break;
+	  case('d'):
+	    if(GNU_DOS_LEVEL > 3 && CTRL) goto do_del;
+	    goto do_enter_char; break;
 	  case(DEL_KEY):
+	    if(GNU_DOS_LEVEL > 3) break;
+do_del:
 	    if(sel == 1) 
 	    {
 	      if(selChar == strlen(inputName)) break;
@@ -325,7 +340,12 @@ int openSaveFile(OPEN_SAVE openSave, int showDialog)
 	  /***************************************************/
 	  /***************************************************/
 	  /***************************************************/
+	  case('b'):
+	    if(GNU_DOS_LEVEL > 1 && CTRL) goto do_left;
+	    goto do_enter_char; break;
 	  case(LEFT_KEY):
+	    if(GNU_DOS_LEVEL > 1) break;
+do_left:
 	    //if((openSave == SAVE) && (sel == 1)) {
 	    if(sel == 1) 
 	    {
@@ -396,7 +416,12 @@ int openSaveFile(OPEN_SAVE openSave, int showDialog)
 	  /***************************************************/
 	  /***************************************************/
 	  /***************************************************/
+	  case('f'):
+	    if(GNU_DOS_LEVEL > 1 && CTRL) goto do_right;
+	    goto do_enter_char; break;
 	  case(RIGHT_KEY):
+	    if(GNU_DOS_LEVEL > 1) break;
+do_right:
 	    //if((openSave == SAVE) && (sel == 1)) {
 	    if(sel == 1) 
 	    {
@@ -473,7 +498,12 @@ int openSaveFile(OPEN_SAVE openSave, int showDialog)
 	  /***************************************************/
 	  /***************************************************/
 	  /***************************************************/
+	  case('g'):
+	    if(GNU_DOS_LEVEL > 2 && CTRL) goto do_esc;
+	    goto do_enter_char; break;
 	  case(ESC_KEY):
+	    if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	    refreshView();
 	    return 0;
 	    break;
@@ -629,7 +659,12 @@ int openSaveFile(OPEN_SAVE openSave, int showDialog)
 	  /***************************************************/
 	  /***************************************************/
 	  //Navigate up through dirs and files
+	  case('p'):
+	    if(GNU_DOS_LEVEL > 1 && CTRL) goto do_up;
+	    goto do_enter_char; break;
 	  case(UP_KEY):
+	    if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	    //if((openSave == SAVE) && (sel == 1)) break;
 	    if(sel == 1) break;
 	    //scanDir(".");
@@ -699,7 +734,12 @@ int openSaveFile(OPEN_SAVE openSave, int showDialog)
 	  /***************************************************/
 	  /***************************************************/
 	  //Navigate down through dirs and files
+	  case('n'):
+	    if(GNU_DOS_LEVEL > 1 && CTRL) goto do_down;
+	    goto do_enter_char; break;
 	  case(DOWN_KEY):
+	    if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	    //if((openSave == SAVE) && (sel == 1)) break;
 	    if(sel == 1) break;
 	    //if((firstVisDir+selectedDir) >= (totalDirs+totalFiles)-1) break;
@@ -783,6 +823,7 @@ int openSaveFile(OPEN_SAVE openSave, int showDialog)
 	    break;
 	  default:
 	    //if(openSave == SAVE && sel == 1) {
+do_enter_char:
 	    if(sel == 1) 
 	    {
 	      //if((ch >= 'a' && ch <= 'z') || (ch >= 'A' && ch <= 'Z')  ||
@@ -1005,85 +1046,122 @@ int _openFile()
 
 void checkFileExtension() 
 {
-  int i = strlen(open_file_name);
-  //is it a C source/header file?
-  if((open_file_name[i-1] == 'c' && open_file_name[i-2] == '.') ||
-     (open_file_name[i-1] == 'h' && open_file_name[i-2] == '.')) 
+  //search for the last dot in the filename
+  char *i = strrchr(open_file_name, '.');
+  if(i != NULL)	//was there a dot?
   {
-    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
-    HIGHLIGHT_MODE = C_MODE;
-  //is it a C++ source/header file?
-  } 
-  else if((open_file_name[i-1] == 'C' && open_file_name[i-2] == '.') ||
-	  (open_file_name[i-1] == 'p' && open_file_name[i-2] == 'p' 
-	  && open_file_name[i-3] == 'c' && open_file_name[i-4] == '.') ||
-	  (open_file_name[i-1] == 'P' && open_file_name[i-2] == 'P' 
-	  && open_file_name[i-3] == 'C' && open_file_name[i-4] == '.') ||
-	  (open_file_name[i-1] == 'c' && open_file_name[i-2] == 'c' 
-	  && open_file_name[i-3] == '.') ||
-	  (open_file_name[i-1] == '+' && open_file_name[i-2] == '+' 
-	  && open_file_name[i-3] == 'c' && open_file_name[i-4] == '.') ||
-	  (open_file_name[i-1] == 'x' && open_file_name[i-2] == 'x' 
-	  && open_file_name[i-3] == 'c' && open_file_name[i-4] == '.') ||
-	  (open_file_name[i-1] == 'p' && open_file_name[i-2] == 'p' 
-	  && open_file_name[i-3] == 'h' && open_file_name[i-4] == '.') ||
-	  (open_file_name[i-1] == 'p' && open_file_name[i-2] == 'c' 
-	  && open_file_name[i-3] == '.')) 
+    //check what was the file extension:
+    //is it a C source/header file?
+    if(strcmp(i, ".c") == 0 || strcmp(i, ".h") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = C_MODE;
+    } 
+    //is it a C++ source/header file?
+    else if(strcmp(i, ".C") == 0 || strcmp(i, ".cpp") == 0
+       || strcmp(i, ".CPP") == 0 || strcmp(i, ".cc") == 0
+       || strcmp(i, ".c++") == 0 || strcmp(i, ".cxx") == 0
+       || strcmp(i, ".hpp") == 0 || strcmp(i, ".cp") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = CPP_MODE;
+    } 
+    //is it a shell script file?
+    else if(strcmp(i, ".sh") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = SHELL_MODE;
+    } 
+    //is it a PERL script file?
+    else if(strcmp(i, ".pl") == 0 || strcmp(i, ".PL") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = PERL_MODE;
+    }
+    //is it a texi file?
+    else if(strcmp(i, ".texi") == 0 || strcmp(i, ".txi") == 0
+	    || strcmp(i, ".texinfo") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = TEXI_MODE;
+    }
+    //is it an assembly file?
+    else if(strcmp(i, ".asm") == 0 || strcmp(i, ".ASM") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = ASM_MODE;
+    }
+    //is it python source file?
+    else if(strcmp(i, ".py") == 0 || strcmp(i, ".PY") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = PYTHON_MODE;
+    }
+    //is it JavaScript file?
+    else if(strcmp(i, ".js") == 0 || strcmp(i, ".JS") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = JAVASCRIPT_MODE;
+    }
+    //is it an HTML webpage?
+    else if(strcmp(i, ".html") == 0 || strcmp(i, ".htm") == 0
+	    || strcmp(i, ".HTML") == 0 || strcmp(i, ".HTM") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = HTML_MODE;
+    }
+    //is it a BASIC file?
+    else if(strcmp(i, ".bas") == 0 || strcmp(i, ".BAS") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = BASIC_MODE;
+    }
+    //is it a Pascal file?
+    else if(strcmp(i, ".pas") == 0 || strcmp(i, ".PAS") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = PASCAL_MODE;
+    }
+    //is it a Fortran 77 file?
+    else if(strcmp(i, ".f") == 0 || strcmp(i, ".for") == 0
+	    || strcmp(i, ".F") == 0 || strcmp(i, ".FOR") == 0)
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = F77_MODE;
+    }
+    //NONE of the above...
+    else 
+    { 
+      AUTO_HIGHLIGHTING = 0; BG_COLOR[COLOR_WINDOW] = old_window_color;
+      HIGHLIGHT_MODE = NO_MODE;
+    }//end if
+  }
+  /////////////////////////////////////////////////////////////
+  /////////////////////////////////////////////////////////////
+  //No dot in the file name, check file content
+  /////////////////////////////////////////////////////////////
+  /////////////////////////////////////////////////////////////
+  else
   {
-    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
-    HIGHLIGHT_MODE = CPP_MODE;
-  //is it a shell script file?
-  } 
-  else if((open_file_name[i-1] == 'h' && open_file_name[i-2] == 's' 
-    && open_file_name[i-3] == '.') ||
-	    (strstr(lines[0], "/bin/csh")) || (strstr(lines[0], "/bin/ksh")) ||
-	    (strstr(lines[0], "/bin/sh")) || (strstr(lines[0], "/bin/bash"))) 
-  {
-    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
-    HIGHLIGHT_MODE = SHELL_MODE;
-  //is it a PERL script file?
-  } 
-  else if((open_file_name[i-1] == 'l' && open_file_name[i-2] == 'p' 
-    && open_file_name[i-3] == '.') ||
-	    (strstr(lines[0], "/bin/perl"))) 
-  {
-    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
-    HIGHLIGHT_MODE = PERL_MODE;
-  //is it a texi file?
-  } 
-  else if((open_file_name[i-1] == 'i' && open_file_name[i-2] == 'x' 
-	  && open_file_name[i-3] == 'e' && open_file_name[i-5] == 't'
-	  && open_file_name[i-5] == '.') ||
-	  (open_file_name[i-1] == 'i' && open_file_name[i-2] == 'x' 
-	  && open_file_name[i-3] == 't' && open_file_name[i-4] == '.') ||
-	  (open_file_name[i-8] == 'o' && open_file_name[i-7] == 'f' 
-	  && open_file_name[i-6] == 'n' && open_file_name[i-5] == 'i' 
-	  && open_file_name[i-4] == 'x' && open_file_name[i-3] == 'e' 
-	  && open_file_name[i-2] == 't' && open_file_name[i-1] == '.')) 
-  {
-    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
-    HIGHLIGHT_MODE = TEXI_MODE;
-  //is it an assembly file?
-  } 
-  else if((open_file_name[i-1] == 'm' && open_file_name[i-2] == 's' 
-	   && open_file_name[i-3] == 'a' && open_file_name[i-4] == '.'))
-  {
-    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
-    HIGHLIGHT_MODE = ASM_MODE;
-  //is it python source file?
-  } 
-  else if((open_file_name[i-1] == 'y' && open_file_name[i-2] == 'p' 
-	   && open_file_name[i-3] == '.'))
-  {
-    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
-    HIGHLIGHT_MODE = PYTHON_MODE;
-  //NONE of the above...
-  } 
-  else 
-  { 
-    AUTO_HIGHLIGHTING = 0; BG_COLOR[COLOR_WINDOW] = old_window_color;
-    HIGHLIGHT_MODE = NO_MODE;
-  }//end if
-  
+    //is it a shell script file?
+    if((strstr(lines[0], "/bin/csh")) || (strstr(lines[0], "/bin/ksh")) ||
+       (strstr(lines[0], "/bin/sh")) || (strstr(lines[0], "/bin/bash")))
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = SHELL_MODE;
+    } 
+    //is it a PERL script file?
+    else if(strstr(lines[0], "/bin/perl"))
+    {
+      AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+      HIGHLIGHT_MODE = PERL_MODE;
+    }
+    //NONE of the above...
+    else 
+    { 
+      AUTO_HIGHLIGHTING = 0; BG_COLOR[COLOR_WINDOW] = old_window_color;
+      HIGHLIGHT_MODE = NO_MODE;
+    }//end if
+  }
   if(AUTO_HIGHLIGHTING) loadKeywords(HIGHLIGHT_MODE);
 }
