@@ -59,6 +59,11 @@ typedef enum
   TEXI_MODE,
   ASM_MODE,
   PYTHON_MODE,
+  HTML_MODE,
+  JAVASCRIPT_MODE,
+  BASIC_MODE,
+  PASCAL_MODE,
+  F77_MODE,
   NO_MODE,
 } hmode;
 hmode HIGHLIGHT_MODE;
@@ -71,8 +76,13 @@ hmode HIGHLIGHT_MODE;
 #define COLOR_HBRACES		32
 #define COLOR_HWINDOW		40
 int old_window_color;
-char *keyword[515];
+char *keyword[420];
 int total_keywords;
 void loadKeywords(hmode mode);
 
+//switch auto-indentation on/off
+bool AUTO_INDENT;
+//the string holding the spaces/tabes to indent new lines
+char AUTO_INDENT_STR[100];
+
 #endif
\ No newline at end of file
