@@ -304,7 +304,7 @@ void pasteMarked()
   if(numCut == 0 && numCopy == 0) 
   {
     msgBox("Nothing marked for Cut/Copy.", OK, INFO);
-    setScreenColors(WHITE, BGBLUE);
+    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
     return;
   }
 
@@ -374,7 +374,7 @@ finish:
   CONFIRM_CUT_COPY = 0;
   ABORT_COPY = 0;
   
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   scanDir(cwd);
 } //END OF FUNCTION
 
