@@ -60,22 +60,22 @@ void findFile()
   if(!(searchResultsFile = fopen("/tmp/find", "w+"))) 
   {
     msgBox("Error opening temporary file. Aborting.", OK, ERROR);
-    setScreenColors(WHITE, BGBLUE);
+    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
     fprintf(log_file, "Failed to open /tmp/find file..\n");
     return;
   }
 
   //Set the user interface//
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   drawBox(x, y, h, w, " Find File ", YES);
   fprintf(stdout, "\e[%d;%dH", x+2, y+2);
   fprintf(stdout, "Enter file name to search for:");
-  setScreenColors(BLUE, BGWHITE);
+  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
   fprintf(stdout, "\e[%d;%dH", x+3, y+2);
   for(i = 0; i < MAX_INPUT1_LEN; i++) putchar(' ');
   fprintf(stdout, "\e[%d;%dH", x+9, y+22);
   for(i = 0; i < MAX_INPUT2_LEN; i++) putchar(' ');
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   fprintf(stdout, "\e[%d;%dH", x+6, y+2);
   fprintf(stdout, "Search in:");
   fprintf(stdout, "\e[%d;%dH", x+7, y+2);
@@ -88,7 +88,7 @@ void findFile()
   int bx, by;
     bx = h-1;
     by = y + ((w-16)/2) - 2;
-    setScreenColors(WHITE, BGRED);
+    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
     fprintf(stdout, "\x1b[%d;%dH", bx, by);
     fprintf(stdout, "   OK   ");
     by += 12;
@@ -104,7 +104,7 @@ void findFile()
     switch(ch) 
     {
       case(ESC_KEY): 
-	setScreenColors(WHITE, BGBLUE);
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	return;
       case(SPACE_KEY):
 	if(sel == 0 || sel == 4) 
@@ -115,29 +115,29 @@ void findFile()
       case(ENTER_KEY):
 	if(sel == 1) 
 	{	//select this option if not already selected
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  if(osel != 0) fprintf(stdout, "\e[%d;%dH ", x+7+osel, y+3);
 	  fprintf(stdout, "\e[%d;%dHX", x+7, y+3);
 	  fprintf(stdout, "\e[%d;%dH", x+7, y+3);
 	  osel = 0;
 	}
-	if(sel == 2) 
+	else if(sel == 2) 
 	{	//select this option if not already selected
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  if(osel != 1) fprintf(stdout, "\e[%d;%dH ", x+7+osel, y+3);
 	  fprintf(stdout, "\e[%d;%dHX", x+8, y+3);
 	  fprintf(stdout, "\e[%d;%dH", x+8, y+3);
 	  osel = 1;
 	}
-	if(sel == 3) 
+	else if(sel == 3) 
 	{	//select this option if not already selected
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  if(osel != 2) fprintf(stdout, "\e[%d;%dH ", x+7+osel, y+3);
 	  fprintf(stdout, "\e[%d;%dHX", x+9, y+3);
 	  fprintf(stdout, "\e[%d;%dH", x+9, y+3);
 	  osel = 2;
 	}
-	if(sel == 0 || sel == 5) 
+	else if(sel == 0 || sel == 5) 
 	{	//pressed ENTER on OK button or on the first input field
 	  if(input1_len <= 0) return;	//if no input entered, just return
 	  findFileName[input1_len] = '\0';
@@ -288,11 +288,11 @@ void findFile()
 	  } 
 	  else if(sel == 4) 
 	  {	    
-	    setScreenColors(GREEN, BGRED);
+	    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, "   OK   ");
 	    by += 12;
-	    setScreenColors(WHITE, BGRED);
+	    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, " CANCEL ");
 	    sel = 5;
@@ -301,11 +301,11 @@ void findFile()
 	  } 
 	  else if(sel == 5) 
 	  {
-	    setScreenColors(WHITE, BGRED);
+	    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, "   OK   ");
 	    by += 12;
-	    setScreenColors(GREEN, BGRED);
+	    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, " CANCEL ");
 	    sel = 6;
@@ -314,7 +314,7 @@ void findFile()
 	  } 
 	  else 
 	  {
-	    setScreenColors(WHITE, BGRED);
+	    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, "   OK   ");
 	    by += 12;
@@ -324,14 +324,15 @@ void findFile()
 	    //adjust cursor to point at input field
 	    fprintf(stdout, "\x1b[%d;%dH", x+3, y+highlight1+2);
 	  }
-	setScreenColors(WHITE, BGBLUE);
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	break;
       case(BACKSPACE_KEY):
 	if(sel == 0) 
 	{
 	  if(input1_len == 0) break;
 	  if(highlight1 == 0) break;
-	  setScreenColors(BLUE, BGWHITE);
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], 
+			  BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	  for(i = --highlight1; i < input1_len; i++) 
 	    findFileName[i] = findFileName[i+1];
 	  findFileName[i] = '\0';
@@ -347,7 +348,8 @@ void findFile()
 	{
 	  if(input2_len == 0) break;
 	  if(highlight2 == 0) break;
-	  setScreenColors(BLUE, BGWHITE);
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], 
+			  BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	  for(i = --highlight2; i < input2_len; i++) 
 	    findInDir[i] = findInDir[i+1];
 	  findInDir[i] = '\0';
@@ -367,7 +369,8 @@ enterNewChar:
 	    if(sel == 0) 
 	    {
 	      if(strlen(findFileName) >= MAX_INPUT1_LEN) break;
-	      setScreenColors(BLUE, BGWHITE);
+	      setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], 
+			  BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	    //inserting in the middle of a string means we need to shift all
 	    //chars one position to the right before inserting the new char
 	    //at the highlighted position.
@@ -392,7 +395,8 @@ enterNewChar:
 	    else if(sel == 4) 
 	    {	//the second input field
 	      if(strlen(findInDir) >= MAX_INPUT2_LEN) break;
-	      setScreenColors(BLUE, BGWHITE);
+	      setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], 
+			  BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	    //inserting in the middle of a string means we need to shift all
 	    //chars one position to the right before inserting the new char
 	    //at the highlighted position.
@@ -418,7 +422,7 @@ enterNewChar:
  }
   //do {;} while (!getchar());
   //free(tmpC);
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   return;
 }
 
@@ -547,12 +551,12 @@ void scanDirForFile(char tmp[], int level)
     else 
     {
       fprintf(log_file, "Search finished. %d files were found\n", nf);
-      fprintf(searchResultsFile, "%04d", nf);
+      fprintf(searchResultsFile, "%06d", nf);
       fflush(searchResultsFile);
       showSearchResults();
       fclose(searchResultsFile);
     }
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   } 
   else chdir("..");
   
@@ -598,24 +602,31 @@ int compareFileName(char *name)
  * *******************************************/
 void showSearchResults() 
 {
-  int lineStart[255];
+  int lineStart[500];
   int i, j, k, l;
-  char buf[4096*4];
+  int buf_size = 4096;
+  char buf[buf_size];
   int buf_len = 0;
   int moreLines = 0;
   int firstVisLine = 0;
-  char totalResultsC[4];
+  char totalResultsC[6];
   int totalResults;
+  int page_number = 0;
+  int firstPageEntry = 0;
+  int page_start[100];
+  page_start[0] = 0;
+  int page_firstVisFile[100];
+  page_firstVisFile[0] = 0;
   
-  fseek(searchResultsFile, -4, SEEK_END);//read int at end of file
-  i = fread(totalResultsC, sizeof(char), 4, searchResultsFile);
+  fseek(searchResultsFile, -6, SEEK_END);//read int at end of file
+  i = fread(totalResultsC, sizeof(char), 6, searchResultsFile);
   totalResults = atoi(totalResultsC);
   
   drawBox(5, 5, SCREEN_H-5, SCREEN_W-5, " Search results: ", YES);
   fseek(searchResultsFile, 0, SEEK_SET);//reset to beginning of file
   buf_len = fread(buf, sizeof(char), sizeof(buf), searchResultsFile);
   if(!buf_len) return;
-  buf_len -= 4;
+  buf_len -= 6;
   
   i = 0; //counter for the output chars
   j = 6; //counter to keep track of the total number of lines
@@ -627,7 +638,7 @@ void showSearchResults()
   while(i < buf_len) 
   {
     if(j > SCREEN_H-6) { moreLines = 1; break; }
-    if(k > SCREEN_W-14) 
+    if(k > SCREEN_W-14)
     { 
       k = 6; j++; lineStart[l] = i; 
       fprintf(stdout, "\e[%d;%dH   ", j, k);
@@ -655,14 +666,61 @@ void showSearchResults()
 	break;
       case(UP_KEY):
 	if(firstVisLine > 0) { firstVisLine--; goto Refresh; }
+	//check to see if there are more results up there in the file
+	if(page_number > 0)
+	{
+	  //reset to beginning of next page
+	  fseek(searchResultsFile, 
+		//buf_size*page_number
+		page_start[page_number-1], 
+		SEEK_SET);
+	  buf_len = fread(buf, sizeof(char), sizeof(buf), searchResultsFile);
+	  if(!buf_len) return;
+	  buf_len -= 6;
+	  //page_start[page_number] = 
+	  //    page_start[page_number-1]+lineStart[firstVisLine+1];
+	  firstPageEntry = page_firstVisFile[page_number];
+	  firstVisLine = page_firstVisFile[page_number]-1;
+	  page_number--;
+	  i = 0; j = 0;
+	  lineStart[0] = 0;
+	  while(i < buf_len)
+	  {
+	    if(buf[i] == '\n')
+	    { lineStart[++j] == i; }
+	    i++;
+	  }
+	  //lineStart[0] = page_start[page_number];
+	  goto Refresh;
+	}
 	break;
       case(DOWN_KEY):
 	if(moreLines) { firstVisLine++; goto Refresh; }
+	//check to see if there are more results in the file
+	if(firstVisLine+(SCREEN_H-12) < totalResults-1)
+	{
+	  //reset to beginning of next page
+	  fseek(searchResultsFile, 
+		//buf_size*page_number
+		page_start[page_number]+lineStart[firstVisLine+1], 
+		SEEK_SET);
+	  buf_len = fread(buf, sizeof(char), sizeof(buf), searchResultsFile);
+	  if(!buf_len) return;
+	  buf_len -= 6;
+	  page_number++;
+	  page_start[page_number] = 
+	      page_start[page_number-1]+lineStart[firstVisLine+1];
+	  firstPageEntry = firstVisLine+1;
+	  page_firstVisFile[page_number] = page_firstVisFile[page_number-1]+firstPageEntry-1;
+	  firstVisLine = 0;
+	  lineStart[0] = 0;
+	  goto Refresh;
+	}
 	break;
 Refresh:
     i = lineStart[firstVisLine]; j = 6; k = 6; moreLines=0; l=firstVisLine+1;
     //fprintf(stdout,"\e[%d;%dH(%d/%s) ",j,k, firstVisLine+j-5, totalResults);
-    fprintf(stdout, "\e[%d;%dH(%d/%d) ", j, k, l, totalResults);
+    fprintf(stdout, "\e[%d;%dH(%d/%d) ", j, k, l+page_firstVisFile[page_number], totalResults);
     while(i < buf_len) 
     {
       if(j > SCREEN_H-6) { moreLines = 1; break; }
@@ -674,11 +732,11 @@ Refresh:
       }
       if(buf[i] == '\n') 
       { 
-	printf("%*s", SCREEN_W-k-13, " ");//finish line with spaces
+	printf("%*s", SCREEN_W-k-19, " ");//finish line with spaces
 	k = 6; j++; lineStart[l] = ++i; l++;
-	if(l > totalResults) break;
+	if(l+page_firstVisFile[page_number] > totalResults) break;
 	if(j > SCREEN_H-6) { moreLines = 1; break; }
-	fprintf(stdout, "\e[%d;%dH(%d/%d) ", j, k, l, totalResults);
+	fprintf(stdout, "\e[%d;%dH(%d/%d) ", j, k, l+page_firstVisFile[page_number], totalResults);
 	continue; 
       }
       putchar(buf[i++]);
