@@ -21,6 +21,7 @@
 #include "../corelib/dialogs.h"
 #include "defs.h"
 #include "edit.h"
+#include "options.h"
 //#include "print.h"
 #include "find.h"
 #include "cutcopy.h"
@@ -44,7 +45,7 @@ time_t tm;
 static int one(const struct dirent *unused);
 
 int read_config_file();
-int write_config_file();
+int write_config_file_defaults();
 int NEW_GNU_DOS_LEVEL = 0;
 
 //extern int PRINTING;
@@ -52,6 +53,8 @@ int NEW_GNU_DOS_LEVEL = 0;
 //extern void freePrinters();
 //extern int findInstalledPrinters();
 
+extern void parse_args(int argc, char **argv);
+
 extern void showFileMenu(int visible);
 extern void showHelpMenu(int visible);
 extern void showEditMenu(int visible);
@@ -88,12 +91,13 @@ void sighandler(int signo)
       if(i == YES) 
       { 	//exit gracefully
 	clearScreen(); 
-	setScreenColors(WHITE, BGBLACK);
-	fprintf(log_file, "Restoring terminal..\n");
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	fprintf(log_file, "Restoring terminal [ OK ]..\n");
 	restoreTerminal();
 	tm = time(NULL);
-	fprintf(log_file, "Closing files and Exiting Prime..\n");
+	fprintf(log_file, "Closing files and Exiting Prime [ OK ]..\n");
 	fprintf(log_file, "System time and date: %s", ctime(&tm));
+	write_config_file();
 	fcloseall();
 	//freePrinters();
 	clearScreen(); 
@@ -101,7 +105,7 @@ void sighandler(int signo)
       } 
       else 
       {
-	setScreenColors(WHITE, BGBLUE);
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	refreshFileView();
 	refreshDirView();
       }//end inner if
@@ -121,191 +125,27 @@ struct sigaction sa;
  * *************************************/
 int main(int argc, char **argv) 
 {
-  if(argc > 1) 
-  {
-   int i;
-   for(i = 1; i < argc; i++) 
-   {
-    if(strcmp(argv[i], "--level1") == 0 || strcmp(argv[i], "-l1") == 0)
-      NEW_GNU_DOS_LEVEL = 1;
-    else if(strcmp(argv[i], "--level2") == 0 || strcmp(argv[i], "-l2") == 0)
-      NEW_GNU_DOS_LEVEL = 2;
-    else if(strcmp(argv[i], "--level3") == 0 || strcmp(argv[i], "-l3") == 0)
-      NEW_GNU_DOS_LEVEL = 3;
-    else if(strcmp(argv[i], "--level4") == 0 || strcmp(argv[i], "-l4") == 0)
-      NEW_GNU_DOS_LEVEL = 4;
-    else if(strcmp(argv[i], "--level5") == 0 || strcmp(argv[i], "-l5") == 0)
-      NEW_GNU_DOS_LEVEL = 5;
-    else if(strcmp(argv[i], "--no-log") == 0) 
-    {
-      //******Start Prime with no log information
-      log_file = fopen("/dev/null", "w");
-    } 
-    else if(strcmp(argv[i], "--version" ) == 0
-	    || strcmp(argv[i], "-v")) 
-    {
-      //******Show version
-      printf("\nPrime version 1.1.\n");
-    } 
-    else if(strcmp(argv[i], "--export") == 0
-	    || strcmp(argv[i], "-e") == 0) 
-    {
-      //******Export directory tree
-      if(argc < 4) 
-      {
-	printf("\nMissing arguments: %s -e|--export dirname filename\n"
-	"\nWhere: dirname is the name of directory whose tree is to be read\n"
-	"       filename is the file to which the dir tree is to be written\n"
-	     , argv[0]);
-	exit(1);
-      }
-      exportTreeFromCommandLine(argv[i+1], argv[i+2]);
-      i += 2;
-      //exit(0);
-    } 
-    else if(strcmp(argv[i], "--dir") == 0
-	    || strcmp(argv[i], "-d") == 0) 
-    {
-      //******Start with directory dir
-      if(argc < 3) 
-      {
-	printf("\nMissing arguments: %s -d|--dir dirname\n"
-	     "\nWhere: dirname is the name of directory to load into Prime\n"
-	     , argv[0]);
-	exit(1);
-      }
-      //check for '~'in dir name
-      char *tmp = (char *) malloc(MAX_DIR_NAME_LEN);
-      strcpy(tmp, argv[i+1]);
-      if(strchr(tmp, '~')) 
-      {
-	char *tmp2 = (char *) malloc(MAX_DIR_NAME_LEN);
-	strcpy(tmp2, argv[i+1]+((strchr(tmp, '~')+1)-tmp));
-	if((pass = getpwuid(geteuid())))
-	  printf("\nError: couldn't open home directory.\n");
-	strcpy(tmp, pass->pw_dir);
-	strcat(tmp, "/");
-	strcat(tmp, tmp2);
-	strcat(tmp, "\0");
-	free(tmp2);
-      }
-      struct stat st;
-      if(stat(tmp, &st) == -1) 
-      {
-	printf("Directory '%s' doesn't exist.\n", tmp);
-	printf("Starting Prime from current working directory.\n");
-	printf("Press any key..");
-	char c = getchar();
-      } 
-      else chdir(tmp);
-      //continue to the rest of program startup....
-      free(tmp);
-      //Open log file
-      if((pass = getpwuid(geteuid())))
-	printf("\nError: couldn't open home directory.\n");
-      log_file_name = (char *) malloc(strlen(pass->pw_dir)+8);
-      strcpy(log_file_name, pass->pw_dir);
-      strcat(log_file_name, "/");
-      strcat(log_file_name, "Prime.log");
-      if(!(log_file = fopen(log_file_name, "w"))) 
-      {
-	printf("\nFatal error: couldn't open logfile 'Prime.log'.\n"
-	  "If you want to start Prime with no log, type './prime --no-log'\n"
-	  "Aborting.\n");
-	exit(1);
-      }
-      i++;
-    } 
-    else if(strcmp(argv[i], "--help") == 0 
-	    || strcmp(argv[i], "-h") == 0) 
-    {
-      //******Show command line help
-      printf("Prime for GNU/Linux, Version 1.1\n"
-	     "By Mohammed Isam, 2013, 2014\n"
-	     "Prime is a GNU software, as part of the GnuDOS package\n\n"
-	     "Prime is a file manager for the GNU/Linux console/xterm.\n"
-	     "It was developed with ease of use and simplicity in mind.\n"
-	     "\nUsage: %s [options] [log-file-name]\n"
-	     "\nOptions:\n  --no-log:\tstart Prime with no log information\n"
-	     "  [-e, --export] dirname filename:\n"
-	     "	\texport directory tree of 'dirname' into 'filename'\n"
-	     "  [-d,--dir] dirname:\n"
-	     "  \tdirname is the name of directory to load into Prime\n"
-	     "  --help, -h:\tshow this help\n\nlog-file-name:\tthe name"
-	     " of a file to be used as log instead of default 'Prime.log'\n",
-	     argv[0]);
-      exit(0);
-    } 
-    else 
-    {
-      //******Open specified file as log file
-      log_file_name = (char *) malloc(strlen(argv[i]));
-      strcpy(log_file_name, argv[i]);
-      if(!(log_file = fopen(log_file_name, "w"))) 
-      {
-	printf("Error: couldn't open logfile '%s'.\n", log_file_name);
-	printf("Would you like to use default file 'Prime.log'? [Y/n]:");
-	char c = getchar();
-	if(c == 'Y' || c == 'y' || c == '\n') 
-	{
-	  if((pass = getpwuid(geteuid())))
-	    printf("\nError: couldn't open home directory.\n");
-	  log_file_name = (char *) malloc(strlen(pass->pw_dir)+8);
-	  strcpy(log_file_name, pass->pw_dir);
-	  strcat(log_file_name, "/");
-	  strcat(log_file_name, "Prime.log");
-	  if(!(log_file = fopen(log_file_name, "w"))) 
-	  {
-	    printf("\nFatal error: couldn't open logfile 'Prime.log'. Aborting.\n");
-	    exit(1);
-	  }
-	} 
-	else 
-	{
-	    printf("Couldn't open logfile. If you want to start Prime with no \
-log, type './prime --no-log'\n");
-	    exit(1);
-	}
-      }
-    }
-   }
-  } 
-  else 
-  {
-    OpenLog:
-    if((pass = getpwuid(geteuid())))
-      printf("\nError: couldn't open home directory.\n");
-    log_file_name = (char *) malloc(strlen(pass->pw_dir)+8);
-    strcpy(log_file_name, pass->pw_dir);
-    strcat(log_file_name, "/");
-    strcat(log_file_name, "Prime.log");
-    if(!(log_file = fopen(log_file_name, "w"))) {
-      printf("\nFatal error: couldn't open logfile 'Prime.log'.\n"
-	  "If you want to start Prime with no log, type './prime --no-log'\n"
-	  "Aborting.\n");
-      exit(1);
-    }
-  }
- //}
- read_config_file();
+  parse_args(argc, argv);
  
  cwd = getcwd(NULL, 0);
  tm = time(NULL);
  if(!log_file)
-	{
-	    printf("Couldn't open logfile. If you want to start Prime with no \
-log, type './prime --no-log'\n");
+ {
+	    printf("Couldn't open logfile. If you want to start Prime with no "
+		   "log, type '%s --no-log'\n", argv[0]);
 	    exit(1);
-	}
+ }
  fprintf(log_file, "Starting Prime in: %s\n", cwd);
  fprintf(log_file, "System time and date: %s", ctime(&tm));
  fprintf(log_file, "Log_file: %s\n", log_file_name);
  fprintf(log_file, "Program started: in the main function..\n");
  init();			//some initialization code
  fprintf(log_file, "Initializing variables [ OK ]..\n");
+ read_config_file();
+ fprintf(log_file, "Reading configuration file [ OK ]..\n");
  
  clearScreen();			//clear the screen
- setScreenColors(WHITE, BGBLUE);
+ setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
  //draw main window
  drawBox(1, 1, SCREEN_H, SCREEN_W, " Prime for GNU/Linux ", YES);
  drawMenuBar(2, 2, SCREEN_W-2); //draw main menu bar
@@ -334,7 +174,7 @@ log, type './prime --no-log'\n");
  int ch;
  while(!end) 
  {	//infinite program loop//
-  fprintf(log_file, "Waiting for user input..\n");
+  fprintf(log_file, "Main loop: Waiting for user input..\n");
   ch = getKey();
   switch(ch) 
   {
@@ -345,8 +185,9 @@ do_del:
      {
        if(activeWindow == DIR_WIN) 
        {
-	 int k = msgBox("Are you sure you want to delete\nthis directory and \
-all its subdirectories?", YES|NO, CONFIRM);
+	 int k = msgBox("Are you sure you want to delete\n"
+			"this directory and all its "
+			"subdirectories?", YES|NO, CONFIRM);
 	 if(k == YES) 
 	 {
 	   deleteThisDir(dirs[firstVisDir+selectedDir], 0);
@@ -363,7 +204,7 @@ all its subdirectories?", YES|NO, CONFIRM);
      {//end outer if
        deleteMarked();
      }//end outer else
-     setScreenColors(WHITE, BGBLUE);
+     setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
      scanDir(cwd);
      break;
    case(UP_KEY):
@@ -380,11 +221,8 @@ do_up:
        else 
        {
 	int j;
-	setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+selectedDir+1]-'a'], BGBLUE);
-	//setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+selectedDir+1]-'a'], BG_COLOR[COLOR_WINDOW]);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedDir+5, 3, dirHighLight);
-	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedDir+5, 3, 
-	//	dirStar[firstVisDir+selectedDir+1], dirs[firstVisDir+selectedDir+1]);
 	if(strlen(dirs[firstVisDir+selectedDir+1]) >= MAX_DIR_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", selectedDir+5, 3, 
@@ -399,10 +237,8 @@ do_up:
 		    dirStar[firstVisDir+selectedDir+1], 
 		    dirs[firstVisDir+selectedDir+1]);
 	}//end if
-	setScreenColors(BLUE, BGWHITE);
+	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedDir+4, 3, dirHighLight);
-	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedDir+4, 3, 
-	//	dirStar[firstVisDir+selectedDir], dirs[firstVisDir+selectedDir]);
 	if(strlen(dirs[firstVisDir+selectedDir]) >= MAX_DIR_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", selectedDir+4, 3, 
@@ -431,12 +267,9 @@ do_up:
        } 
        else 
        {
-	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+selectedFile+1]-'a'], BGBLUE);
-	//setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+selectedFile+1]-'a'], BG_COLOR[COLOR_WINDOW]);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedFile+5, 
 		(SCREEN_W/2)+1, fileHighLight);
-	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedFile+5, (SCREEN_W/2)+1, 
-	//	      fileStar[firstVisFile+selectedFile+1], files[firstVisFile+selectedFile+1]);
 	if(strlen(files[firstVisFile+selectedFile+1]) >= MAX_DIR_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", selectedFile+5, (SCREEN_W/2)+1, 
@@ -451,11 +284,9 @@ do_up:
 		    fileStar[firstVisFile+selectedFile+1], 
 		    files[firstVisFile+selectedFile+1]);
 	}//end if
-	setScreenColors(BLUE, BGWHITE);
+	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedFile+4, 
 		(SCREEN_W/2)+1, fileHighLight);
-	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedFile+4, (SCREEN_W/2)+1, 
-	//	      fileStar[firstVisFile+selectedFile], files[firstVisFile+selectedFile]);
 	if(strlen(files[firstVisFile+selectedFile]) >= MAX_DIR_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", selectedFile+4, (SCREEN_W/2)+1, 
@@ -493,11 +324,8 @@ do_down:
        else 
        {
 	 int j;
-	setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+selectedDir-1]-'a'], BGBLUE);
-	//setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+selectedDir-1]-'a'], BG_COLOR[COLOR_WINDOW]);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedDir+3, 3, dirHighLight);
-	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedDir+3, 3, 
-	//	dirStar[firstVisDir+selectedDir-1], dirs[firstVisDir+selectedDir-1]);
 	if(strlen(dirs[firstVisDir+selectedDir-1]) >= MAX_DIR_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", selectedDir+3, 3, 
@@ -512,10 +340,8 @@ do_down:
 		    dirStar[firstVisDir+selectedDir-1], 
 		    dirs[firstVisDir+selectedDir-1]);
 	}//end if
-	setScreenColors(BLUE, BGWHITE);
+	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedDir+4, 3, dirHighLight);
-	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedDir+4, 3, 
-	//	dirStar[firstVisDir+selectedDir], dirs[firstVisDir+selectedDir]);
 	if(strlen(dirs[firstVisDir+selectedDir]) >= MAX_DIR_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", selectedDir+4, 3, 
@@ -549,12 +375,9 @@ do_down:
        else 
        {
 	 int j;
-	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+selectedFile-1]-'a'], BGBLUE);
-	//setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+selectedFile-1]-'a'], BG_COLOR[COLOR_WINDOW]);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedFile+3, 
 		(SCREEN_W/2)+1, fileHighLight);
-	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedFile+3, (SCREEN_W/2)+1, 
-	//	      fileStar[firstVisFile+selectedFile-1], files[firstVisFile+selectedFile-1]);
 	if(strlen(files[firstVisFile+selectedFile-1]) >= MAX_DIR_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", selectedFile+3, 
@@ -569,11 +392,9 @@ do_down:
 		    fileStar[firstVisFile+selectedFile-1], 
 	   files[firstVisFile+selectedFile-1]);
 	}//end if
-	setScreenColors(BLUE, BGWHITE);
+	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedFile+4, 
 		(SCREEN_W/2)+1, fileHighLight);
-	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedFile+4, (SCREEN_W/2)+1, 
-	//	      fileStar[firstVisFile+selectedFile], files[firstVisFile+selectedFile]);
 	if(strlen(files[firstVisFile+selectedFile]) >= MAX_DIR_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", selectedFile+4, 
@@ -604,7 +425,7 @@ do_down:
      if(ALT) 
      {
        showPropertiesDialog();
-       setScreenColors(WHITE, BGBLUE);
+       setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
        scanDir(cwd);
        break;
      }
@@ -615,7 +436,7 @@ do_down:
         scanDir(dirs[firstVisDir+selectedDir]);
       } break;
      }
-   case(SPACE_KEY):			//toggle select/unselect file or directory
+   case(SPACE_KEY):		//toggle select/unselect file or directory
      toggleSelected();
      break;
    case('s'):
@@ -623,7 +444,7 @@ do_down:
      {
       if(GNU_DOS_LEVEL <= 4) break;
       findFile();
-      setScreenColors(WHITE, BGBLUE);
+      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
       scanDir(cwd);
      } 
      else goto insert_char;
@@ -631,10 +452,10 @@ do_down:
    case('f'):
      if(ALT) 
      {
-      if(GNU_DOS_LEVEL > 1) break;
+      //if(GNU_DOS_LEVEL > 1) break;
       fprintf(log_file, "Opening file menu..\n");
       showFileMenu(YES);
-      fprintf(log_file, "Waiting for user input..\n");
+      fprintf(log_file, "Closed file menu, Waiting for user input..\n");
       break;
      } 
      else if(CTRL) 
@@ -642,7 +463,7 @@ do_down:
    //case(CTRL_F_KEY):			//open the find file dialog box
       if(GNU_DOS_LEVEL > 4) break;
       findFile();
-      setScreenColors(WHITE, BGBLUE);
+      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
       scanDir(cwd);
      } 
      else goto insert_char;
@@ -652,32 +473,29 @@ do_down:
      if(CTRL) 
      {
        if(GNU_DOS_LEVEL > 2) goto do_end;
+   //case(CTRL_E_KEY):
+      exportTree(YES);
+      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+      scanDir(cwd);
      }
      else if(ALT) 
      {
-      if(GNU_DOS_LEVEL > 1) break;
+      //if(GNU_DOS_LEVEL > 1) break;
       fprintf(log_file, "Opening edit menu..\n");
       showEditMenu(YES);
-      fprintf(log_file, "Waiting for user input..\n");
+      fprintf(log_file, "Closed edit menu, Waiting for user input..\n");
       break;
      } 
-     else if(CTRL) 
-     {
-   //case(CTRL_E_KEY):
-      exportTree(YES);
-      setScreenColors(WHITE, BGBLUE);
-      scanDir(cwd);
-     } 
      else goto insert_char;
      break;
    //case(ALT_H_KEY):			//showup the help menu
    case('h'):
      if(ALT) 
      {
-      if(GNU_DOS_LEVEL > 1) break;
+      //if(GNU_DOS_LEVEL > 1) break;
       fprintf(log_file, "Opening help menu..\n");
       showHelpMenu(YES);
-      fprintf(log_file, "Waiting for user input..\n");
+      fprintf(log_file, "Closed help menu, Waiting for user input..\n");
      } 
      else goto insert_char;
      break;
@@ -685,8 +503,30 @@ do_down:
    case('x'):
      if(CTRL) 
      {
-      if(GNU_DOS_LEVEL >= 4) break;
-      cutMarked();			//found in edit.c
+      if(GNU_DOS_LEVEL > 4)
+      {
+	int k=(int)SCREEN_H/2;
+	int l=(int)SCREEN_W/2;
+	drawBox(k-1, l-23, k+1, l+23, NULL, YES);
+	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+	fprintf(stdout, "\e[%d;%dH", k, l-22);
+	fprintf(stdout, "[C-c] Quit  [C-f] Open location [C-g] Cancel");
+	int loop = 1;
+	while(loop)
+	{
+	  ch = getKey();
+	  if(ch == 'c' && CTRL) goto do_exit;
+	  else if(ch == 'f' && CTRL) goto do_open_location;
+	  else if(ch == 'g' && CTRL)
+	  {
+	    refreshDirView();
+	    refreshFileView();
+	    loop = 0;
+	    break;
+	  }
+	}//end while
+      }
+      else cutMarked();			//found in edit.c
      } 
      else goto insert_char;
      break;
@@ -694,7 +534,7 @@ do_down:
    case('v'):
      if(CTRL) 
      {
-       if(GNU_DOS_LEVEL > 2) break;
+       if(GNU_DOS_LEVEL > 3) break;
        pasteMarked();
      } 
      else goto insert_char;
@@ -703,11 +543,11 @@ do_down:
    case('p'):
      if(CTRL) 
      {
-      if(GNU_DOS_LEVEL > 1) goto do_down;
+      if(GNU_DOS_LEVEL > 1) goto do_up;
       msgBox("Oops! This function is currently not implemented.", OK, INFO);
       //fprintf(log_file, "Showing Print dialog box..\n");
       //showPrintDialogBox();
-      setScreenColors(WHITE, BGBLUE);
+      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	refreshFileView();
 	refreshDirView();
      }
@@ -722,7 +562,7 @@ do_down:
       if(activeWindow == DIR_WIN)
 	fprintf(log_file, "Selecting All directories..\n");
       else fprintf(log_file, "Selecting All files..\n");
-      setScreenColors(WHITE, BGBLUE);
+      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
       refreshFileView();
       refreshDirView();
       refreshBottomView();
@@ -736,7 +576,7 @@ do_down:
       if(GNU_DOS_LEVEL < 4)
       {
 	clearSelection();
-	fprintf(log_file, "Clearing all selections..\n");
+	fprintf(log_file, "Clearing all selections [ OK ]..\n");
       }
       else
       {
@@ -748,6 +588,8 @@ do_down:
    case('o'):
     if(CTRL) 
     {
+     if(GNU_DOS_LEVEL > 4) break;
+do_open_location:
      if(1) ;
      char *res = inputBox("Enter directory path to open:", "Open Location");
      if(res != NULL) 
@@ -777,6 +619,12 @@ do_down:
      fprintf(log_file, "Opening '%s'..\n", res);
      //free(res);
     } 
+    else if(ALT)
+    {//open options menu
+      fprintf(log_file, "Opening options menu..\n");
+      showOptionsMenu(YES);
+      fprintf(log_file, "Closed options menu, Waiting for user input..\n");
+    }
     else goto insert_char;
     break;
    case(HOME_KEY):
@@ -849,21 +697,22 @@ do_exit:
       int i = msgBox("Are you sure you want to exit?", YES | NO, CONFIRM);
       if(i == YES) 
       { 	//exit gracefully
-	setScreenColors(WHITE, BGBLACK);
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	clearScreen(); 
-	fprintf(log_file, "Restoring terminal..\n");
+	fprintf(log_file, "Restoring terminal [ OK ]..\n");
 	restoreTerminal();
 	tm = time(NULL);
-	fprintf(log_file, "Closing files and Exiting Prime..\n");
+	fprintf(log_file, "Closing files and Exiting Prime [ OK ]..\n");
 	fprintf(log_file, "System time and date: %s", ctime(&tm));
+	write_config_file();
 	fcloseall();
-	setScreenColors(WHITE, BGBLACK);
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	clearScreen(); 
 	exit(0); 
       } 
       else 
       {
-	setScreenColors(WHITE, BGBLUE);
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	refreshFileView();
 	refreshDirView();
       }//end inner if
@@ -879,9 +728,14 @@ do_exit:
      else goto insert_char;
      break;
    //case(CTRL_Z_KEY):
+   case('/'):
+     if(CTRL && GNU_DOS_LEVEL > 4) goto do_undo;
+     break;
    case('z'):
      if(CTRL) 
      {
+     if(GNU_DOS_LEVEL > 4) break;
+do_undo:
       unMarkAll();
       if(activeWindow == DIR_WIN)
 	fprintf(log_file, "Deselecting All directories..\n");
@@ -988,14 +842,15 @@ insert_char:
      }//end if1
      break;
   }//end switch
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
  }//end while
  
- fprintf(log_file, "Restoring terminal..\n");
+ fprintf(log_file, "Restoring terminal [ OK ]..\n");
  restoreTerminal();
- fprintf(log_file, "Closing files and Exiting Prime..\n");
+ fprintf(log_file, "Closing files and Exiting Prime [ OK ]..\n");
  time_t tm = time(NULL);
  fprintf(log_file, "System time and date: %s", ctime(&tm));
+ write_config_file();
  fcloseall();
  //freePrinters();
  exit(0);
@@ -1003,7 +858,7 @@ insert_char:
 
 void toggleSelected() 
 {
-  setScreenColors(BLUE, BGWHITE);
+  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
   switch(activeWindow) 
   {
     case(DIR_WIN):
@@ -1030,7 +885,7 @@ void toggleSelected()
       }//end outer if				//and then print it!!
       fprintf(stdout, "\e[%d;%dH", selectedDir+4, 3);
       fprintf(stdout, "%c", dirStar[firstVisDir+selectedDir]);
-      setScreenColors(WHITE, BGBLUE);
+      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
       refreshBottomView();
       fprintf(stdout, "\e[3;3H");	//move cursor to point to window
       break;
@@ -1057,7 +912,7 @@ void toggleSelected()
       }//end outer if				//and then print it!!
       fprintf(stdout, "\e[%d;%dH", selectedFile+4, (SCREEN_W/2)+1);
       fprintf(stdout, "%c", fileStar[firstVisFile+selectedFile]);
-      setScreenColors(WHITE, BGBLUE);
+      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
       refreshBottomView();
       fprintf(stdout, "\e[3;%dH",(SCREEN_W/2)+2);//cursor to point to window
       break;
@@ -1081,7 +936,7 @@ void scanDir(char *dir)
   if(n >= 0) 
   {
     int cnt;
-    fprintf(log_file, "Scanning directory '%s'\n", dir);
+    fprintf(log_file, "Scanning directory '%s'\n", cwd);
     for(cnt = 0; cnt < n; ++cnt) 
     {
       lstat(eps[cnt]->d_name,&statbuf);
@@ -1147,10 +1002,10 @@ void scanDir(char *dir)
   } 
   else 
   {
-    fprintf(log_file, "Error opening dir: %s\n", dir);
-    dcount = msgBox("Cannot open directory.\nProbably bad path specified or \
-access denied.", OK, ERROR);
-    setScreenColors(WHITE, BGBLUE);
+    fprintf(log_file, "Error opening dir: %s\n", cwd);
+    dcount = msgBox("Cannot open directory.\nProbably bad path specified "
+		    "or access denied.", OK, ERROR);
+    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
     refreshFileView();
     refreshDirView();
     return;
@@ -1172,7 +1027,7 @@ access denied.", OK, ERROR);
     refreshFileView();
     refreshDirView();
     refreshBottomView();
-    fprintf(log_file, "Finished scanning directory '%s'..\n", dir);
+    fprintf(log_file, "Finished scanning directory '%s'..\n", cwd);
 }
 
 static int one(const struct dirent *unused) 
@@ -1188,7 +1043,7 @@ static int one(const struct dirent *unused)
  * **************************************/
 void refreshDirView() 
 {
- if(activeWindow == DIR_WIN) setScreenColors(GREEN, BGBLUE);
+ if(activeWindow == DIR_WIN) setScreenColors(GREEN, BG_COLOR[COLOR_WINDOW]);
  //draw left sub-window
  drawBox(3, 2, SCREEN_H-5, (int)(SCREEN_W/2)-1, " Directory view ", YES);
  int i, j;
@@ -1199,13 +1054,13 @@ void refreshDirView()
    refreshDirView();//this will make an infinite loop.. solution??
    return;
  }
- //setScreenColors(GREEN, BGBLUE);
+ //setScreenColors(GREEN, BG_COLOR[COLOR_WINDOW]);
  for(i = 0; i < numVisDirs; i++) 
  {
    if(dirs[firstVisDir+i] == NULL) break; 
-   if(i == selectedDir) 
+   if(i == selectedDir && activeWindow == DIR_WIN) 
    {
-      setScreenColors(BLUE, BGWHITE);
+      setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
       fprintf(stdout, "\x1b[%d;%dH%s", i+4, 3, dirHighLight);
       if(strlen(dirs[firstVisDir+i]) >= MAX_DIR_NAME_LEN) {
 	fprintf(stdout, "\x1b[%d;%dH%c", i+4, 3, dirStar[firstVisDir+i]);
@@ -1218,11 +1073,11 @@ void refreshDirView()
 	fprintf(stdout, "\x1b[%d;%dH%c%s", i+4, 3, 
 		dirStar[firstVisDir+i], dirs[firstVisDir+i]);
       }//end if
-      //setScreenColors(GREEN, BGBLUE);
+      //setScreenColors(GREEN, BG_COLOR[COLOR_WINDOW]);
     } 
     else 
     {
-      setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+i]-'a'], BGBLUE);
+      setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+i]-'a'], BG_COLOR[COLOR_WINDOW]);
       if(strlen(dirs[firstVisDir+i]) >= MAX_DIR_NAME_LEN) 
       {
 	fprintf(stdout, "\x1b[%d;%dH%c", i+4, 3, dirStar[firstVisDir+i]);
@@ -1237,7 +1092,7 @@ void refreshDirView()
       }//end if
     }//end if
  }//end for
- setScreenColors(WHITE, BGBLUE);
+ setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
  //redraw main window but don't clear the area
  drawBox(1, 1, SCREEN_H, SCREEN_W, " Prime  for GNU/Linux ", NO);
  
@@ -1255,7 +1110,7 @@ void refreshDirView()
  * **************************************/
 void refreshFileView() 
 {
- if(activeWindow == FILE_WIN) setScreenColors(GREEN, BGBLUE);
+ if(activeWindow == FILE_WIN) setScreenColors(GREEN, BG_COLOR[COLOR_WINDOW]);
  //draw right sub-window
  drawBox(3, (int)(SCREEN_W/2), SCREEN_H-5, SCREEN_W-1, " File view ", YES);
  int i, j;
@@ -1265,13 +1120,13 @@ void refreshFileView()
    files[1] = NULL;
    totalFiles = 1;
  }
- //setScreenColors(GREEN, BGBLUE);
+ //setScreenColors(GREEN, BG_COLOR[COLOR_WINDOW]);
  for(i = 0; i < numVisFiles; i++) 
  {
     if(files[firstVisFile+i] == NULL) break; 
-    if(i == selectedFile) 
+    if(i == selectedFile && activeWindow == FILE_WIN) 
     {
-      setScreenColors(BLUE, BGWHITE);
+      setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
       fprintf(stdout, "\x1b[%d;%dH%s", i+4, (SCREEN_W/2)+1, fileHighLight);
       if(strlen(files[firstVisFile+i]) >= MAX_FILE_NAME_LEN) {
 	fprintf(stdout, "\x1b[%d;%dH%c", i+4, (SCREEN_W/2)+1, 
@@ -1285,11 +1140,11 @@ void refreshFileView()
 	fprintf(stdout, "\x1b[%d;%dH%c%s", i+4, (SCREEN_W/2)+1, 
 		      fileStar[firstVisFile+i], files[firstVisFile+i]);
       }//end if
-      //setScreenColors(GREEN, BGBLUE);
+      //setScreenColors(GREEN, BG_COLOR[COLOR_WINDOW]);
     } 
     else 
     {
-	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+i]-'a'], BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+i]-'a'], BG_COLOR[COLOR_WINDOW]);
 	if(strlen(files[firstVisFile+i]) >= MAX_FILE_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", i+4, (SCREEN_W/2)+1, 
@@ -1305,7 +1160,7 @@ void refreshFileView()
 	}//end if
     }//end if
  }//end for
- setScreenColors(WHITE, BGBLUE);
+ setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   
  if(activeWindow == DIR_WIN) 
    fprintf(stdout, "\e[3;3H");	//move cursor to point to window
@@ -1321,6 +1176,7 @@ void refreshFileView()
 void refreshBottomView() 
 {
   //draw bottom sub-window
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   drawBox(SCREEN_H-4, 2, SCREEN_H-1, SCREEN_W-1, " Quick reference ", YES);
   fprintf(stdout, "\e[%d;%dH", SCREEN_H-2, 4);
   if(cwd != NULL) 
@@ -1357,7 +1213,7 @@ void refreshBottomView()
  * **************************************/
 void drawMenuBar(int x, int y, int w) 
 {
-  setScreenColors(BLUE, BGWHITE);
+  setScreenColors(FG_COLOR[COLOR_MENU_BAR], BG_COLOR[COLOR_MENU_BAR]);
   fprintf(stdout, "\x1b[%d;%dH", x, y);		//reposition the cursor
   int i,j, lastChar=y;
   for(i = 0; i < w; i++) fputc(' ', stdout);	//Draw empty menu bar
@@ -1379,7 +1235,7 @@ void drawMenuBar(int x, int y, int w)
     }
     fprintf(stdout, " ");
   }
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 }
 
 /***************************************
@@ -1391,9 +1247,9 @@ void init()
 {
   getScreenSize();
   //define colors that will be used to colorize the view
-  FILE_DIR_COLOR['d'-'a'] = WHITE;	//color for directories
+  FILE_DIR_COLOR['d'-'a'] = FG_COLOR[COLOR_WINDOW];	//color for directories
   FILE_DIR_COLOR['x'-'a'] = GREEN;	//color for exec files
-  FILE_DIR_COLOR['r'-'a'] = WHITE;	//color for regular files
+  FILE_DIR_COLOR['r'-'a'] = FG_COLOR[COLOR_WINDOW];	//color for regular files
   FILE_DIR_COLOR['l'-'a'] = CYAN;	//color for links
   FILE_DIR_COLOR['a'-'a'] = RED;	//color for archives
   FILE_DIR_COLOR['h'-'a'] = BROWN;	//color for hidden files
@@ -1402,7 +1258,8 @@ void init()
   //1. Main Menu//
   menu[0] = "&File";
   menu[1] = "&Edit";
-  menu[2] = "&Help";
+  menu[2] = "&Options";
+  menu[3] = "&Help";
   //2. File Menu//
   fileMenu[0] = "New directory ^N";
   fileMenu[1] = "Open location ^O";
@@ -1417,7 +1274,10 @@ void init()
   editMenu[4] = "Unmark all ^Z";
   editMenu[5] = "Clear sel. ^W";
   editMenu[6] = "Find..     ^F";
-  //4. Help Menu//
+  //4. Options Menu//
+  optionsMenu[0] = "Change colors  ";
+  optionsMenu[1] = "Reset config   ";
+  //5. Help Menu//
   helpMenu[0] = "View README    ";
   helpMenu[1] = "GNU keybindings";
   helpMenu[2] = "Quick reference";
@@ -1494,12 +1354,37 @@ void init()
   FG_COLOR[COLOR_STATUS_BAR] = 34;
   FG_COLOR[COLOR_BUTTONS] = 37;
   FG_COLOR[COLOR_HBUTTONS] = 32;
-  BG_COLOR[COLOR_WINDOW] = 44;
+  BG_COLOR[COLOR_WINDOW] = 40; //44;
   BG_COLOR[COLOR_HIGHLIGHT_TEXT] = 47;
   BG_COLOR[COLOR_MENU_BAR] = 47;
   BG_COLOR[COLOR_STATUS_BAR] = 47;
   BG_COLOR[COLOR_BUTTONS] = 41;
   BG_COLOR[COLOR_HBUTTONS] = 41;
+  //initiate color arrays
+  COLOR_STR[0] = "BLACK";
+  COLOR_STR[1] = "RED";
+  COLOR_STR[2] = "GREEN";
+  COLOR_STR[3] = "BROWN";
+  COLOR_STR[4] = "BLUE";
+  COLOR_STR[5] = "MAGENTA";
+  COLOR_STR[6] = "CYAN";
+  COLOR_STR[7] = "WHITE";
+  FG_COLOR_ARRAY[0] = 30;
+  FG_COLOR_ARRAY[1] = 31;
+  FG_COLOR_ARRAY[2] = 32;
+  FG_COLOR_ARRAY[3] = 33;
+  FG_COLOR_ARRAY[4] = 34;
+  FG_COLOR_ARRAY[5] = 35;
+  FG_COLOR_ARRAY[6] = 36;
+  FG_COLOR_ARRAY[7] = 37;
+  BG_COLOR_ARRAY[0] = 40;
+  BG_COLOR_ARRAY[1] = 41;
+  BG_COLOR_ARRAY[2] = 42;
+  BG_COLOR_ARRAY[3] = 43;
+  BG_COLOR_ARRAY[4] = 44;
+  BG_COLOR_ARRAY[5] = 45;
+  BG_COLOR_ARRAY[6] = 46;
+  BG_COLOR_ARRAY[7] = 47;
 
  initTerminal();
 }
@@ -1510,7 +1395,8 @@ int read_config_file()
       GNU_DOS_LEVEL = 1;
       if(!(pass = getpwuid(geteuid()))) 
       {
-	printf("Error: couldn't open home directory to read configuration file.\n");
+	printf("Error: couldn't open home directory to read "
+	       "configuration file.\n");
 	printf("Aborting.\n");
 	exit(1);
       }
@@ -1523,7 +1409,7 @@ int read_config_file()
 	printf("Error: couldn't read configuration file in home directory.\n");
 	printf("Resetting configuration file.\n");
 	//exit(1);
-	write_config_file();
+	write_config_file_defaults();
 	config_file = fopen(config_file_name, "r");
       }
 
@@ -1536,15 +1422,63 @@ int read_config_file()
 	{
 	  GNU_DOS_LEVEL = atoi((strchr(buf, '=')+2));
 	}
+	else if (strstr(buf, "FG_COLOR_WIN")) 
+	{
+	  FG_COLOR[COLOR_WINDOW] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "FG_COLOR_HLT")) 
+	{
+	  FG_COLOR[COLOR_HIGHLIGHT_TEXT] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "FG_COLOR_MBAR")) 
+	{
+	  FG_COLOR[COLOR_MENU_BAR] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "FG_COLOR_SBAR")) 
+	{
+	  FG_COLOR[COLOR_STATUS_BAR] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "FG_COLOR_HBUT")) 
+	{
+	  FG_COLOR[COLOR_HBUTTONS] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "FG_COLOR_BUT")) 
+	{
+	  FG_COLOR[COLOR_BUTTONS] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "BG_COLOR_WIN")) 
+	{
+	  BG_COLOR[COLOR_WINDOW] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "BG_COLOR_HLT")) 
+	{
+	  BG_COLOR[COLOR_HIGHLIGHT_TEXT] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "BG_COLOR_MBAR")) 
+	{
+	  BG_COLOR[COLOR_MENU_BAR] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "BG_COLOR_SBAR")) 
+	{
+	  BG_COLOR[COLOR_STATUS_BAR] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "BG_COLOR_HBUT")) 
+	{
+	  BG_COLOR[COLOR_HBUTTONS] = atoi(strchr(buf, '=')+2);
+	}
+	else if (strstr(buf, "BG_COLOR_BUT")) 
+	{
+	  BG_COLOR[COLOR_BUTTONS] = atoi(strchr(buf, '=')+2);
+	}
       }//end while
       fclose(config_file);
       if(NEW_GNU_DOS_LEVEL)
 	GNU_DOS_LEVEL = NEW_GNU_DOS_LEVEL;
-      if(GNU_DOS_LEVEL > 5 || GNU_DOS_LEVEL < 1) GNU_DOS_LEVEL = 1;
+      if(GNU_DOS_LEVEL > 6 || GNU_DOS_LEVEL < 1) GNU_DOS_LEVEL = 1;
       return 1;
 }
 
-int write_config_file()
+int write_config_file_defaults()
 {
       if(!(pass = getpwuid(geteuid()))) 
       {
@@ -1568,6 +1502,19 @@ int write_config_file()
       //write default values to the configuration file
       fprintf(config_file, "#Configuration file for the prime program\n");
       fprintf(config_file, "#Please do not modify this file by hand\n\n");
+      fprintf(config_file, "#Display colors\n");
+      fprintf(config_file, "FG_COLOR_WIN = 37\n");
+      fprintf(config_file, "FG_COLOR_HLT = 34\n");
+      fprintf(config_file, "FG_COLOR_MBAR = 34\n");
+      fprintf(config_file, "FG_COLOR_SBAR = 34\n");
+      fprintf(config_file, "FG_COLOR_HBUT = 32\n");
+      fprintf(config_file, "FG_COLOR_BUT = 37\n");
+      fprintf(config_file, "BG_COLOR_WIN = 40\n");
+      fprintf(config_file, "BG_COLOR_HLT = 47\n");
+      fprintf(config_file, "BG_COLOR_MBAR = 47\n");
+      fprintf(config_file, "BG_COLOR_SBAR = 47\n");
+      fprintf(config_file, "BG_COLOR_HBUT = 41\n");
+      fprintf(config_file, "BG_COLOR_BUT = 41\n\n");
       fprintf(config_file, "#GnuDOS Level\n");
       fprintf(config_file, "GNU_DOS_LEVEL = %d\n", GNU_DOS_LEVEL);
       fclose(config_file);
