@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "defs.h"
+#include "options.h"
 //#include "print.h"
 #include "edit.h"
 #include "sys/stat.h"
@@ -56,9 +57,9 @@ void showFileMenu(int visible)
   {	//show the file menu
     //activeWindow = FILE_MENU;
     drawBox(3, 2, 9, 19, NULL, YES);
-    setScreenColors(BLUE, BGWHITE);
+    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
     fprintf(stdout, "\e[4;3HNew directory ^N");
-    setScreenColors(WHITE, BGBLUE);
+    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
     fprintf(stdout, "\e[5;3HOpen Location ^O");
     fprintf(stdout, "\e[6;3HExport Tree   ^E");
     fprintf(stdout, "\e[7;3HPrint         ^P");
@@ -69,30 +70,48 @@ void showFileMenu(int visible)
       ch = getKey();
       switch(ch) 
       {
+	case('g'):
+	  if(GNU_DOS_LEVEL < 3) break;
+	  if(!CTRL) break;
+	  goto do_esc;
 	case(ESC_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 2) break;
+do_esc:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  refreshFileView();
 	  refreshDirView();
 	  endme = 1;
 	  break;
+	case('p'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_up;
 	case(UP_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_up:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //clear last selection
 	  fprintf(stdout, "\e[%d;3H%s", fSelect+4, fileMenu[fSelect]);
 	  fSelect--;
 	  if(fSelect < 0) fSelect = fTotal-1;
-	  setScreenColors(BLUE, BGWHITE);
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;3H%s", fSelect+4, fileMenu[fSelect]);
 	  fprintf(stdout, "\e[%d;18H", fSelect+4);
 	  break;
+	case('n'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_down;
 	case(DOWN_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_down:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //clear last selection
 	  fprintf(stdout, "\e[%d;3H%s", fSelect+4, fileMenu[fSelect]);
 	  fSelect++;
 	  if(fSelect >= fTotal) fSelect = 0;
-	  setScreenColors(BLUE, BGWHITE);
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;3H%s", fSelect+4, fileMenu[fSelect]);
 	  fprintf(stdout, "\e[%d;18H", fSelect+4);
@@ -102,17 +121,21 @@ void showFileMenu(int visible)
 	 if(ALT) 
 	 {
 	  activeWindow = DIR_WIN;
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  refreshFileView();
 	  refreshDirView();
 	  return;
 	 }
-	  break;
+	 else if(CTRL)
+	   if(GNU_DOS_LEVEL > 1) goto do_right;
+	 break;
 	//case(ALT_E_KEY):	//navigate to Edit menu
 	case('e'):
-	 if(!ALT) break;
+	  if(!ALT) break;
 	case(RIGHT_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_right:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  fprintf(log_file, "Opening edit menu..\n");
 	  refreshFileView();
 	  refreshDirView();
@@ -121,9 +144,16 @@ void showFileMenu(int visible)
 	  break;
 	//case(ALT_H_KEY):	//navigate to Help menu
 	case('h'):
-	 if(!ALT) break;
+	  if(!ALT) break;
+	  goto do_left;
+	case('b'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_left;
 	case(LEFT_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_left:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  fprintf(log_file, "Opening help menu..\n");
 	  refreshFileView();
 	  refreshDirView();
@@ -159,7 +189,7 @@ void showFileMenu(int visible)
 	  if(fSelect == 2) 
 	  {	//user selected 'Export Tree'
 	    exportTree(YES);
-	    setScreenColors(WHITE, BGBLUE);
+	    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	    scanDir(cwd);
 	    endme = 1;
 	    break;
@@ -211,12 +241,12 @@ void showFileMenu(int visible)
 	    i = msgBox("Are you sure you want to exit?", YES | NO, CONFIRM);
 	    if(i == YES) 
 	    { 	//exit gracefully
-	      fprintf(log_file, "Restoring terminal..\n");
+	      fprintf(log_file, "Restoring terminal [ OK ]..\n");
 	      restoreTerminal(); 
-	      fprintf(log_file, "Closing files and Exiting Prime..\n");
-	      setScreenColors(WHITE, BGBLACK);
+	      fprintf(log_file, "Closing files and Exiting Prime [ OK ]..\n");
+	      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	      clearScreen(); 
-	      setScreenColors(WHITE, BGBLACK);
+	      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	      time_t tm = time(NULL);
 	      fprintf(log_file, "System time and date: %s", ctime(&tm));
 	      fcloseall();
@@ -224,7 +254,7 @@ void showFileMenu(int visible)
 	      exit(0); 
 	    }
 	  }
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  refreshFileView();
 	  refreshDirView();
 	  endme = 1;
@@ -259,9 +289,9 @@ void showEditMenu(int visible)
   {	//show the file menu
     //activeWindow = EDIT_MENU;
     drawBox(3, 8, 11, 23, NULL, YES);
-    setScreenColors(BLUE, BGWHITE);
+    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
     fprintf(stdout, "\e[4;9H%s", editMenu[0]);
-    setScreenColors(WHITE, BGBLUE);
+    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
     for(i = 1; i < eTotal; i++) 
     {
       fprintf(stdout, "\e[%d;9H%s", i+4, editMenu[i]);
@@ -273,30 +303,48 @@ void showEditMenu(int visible)
       ch = getKey();
       switch(ch) 
       {
+	case('g'):
+	  if(GNU_DOS_LEVEL < 3) break;
+	  if(!CTRL) break;
+	  goto do_esc;
 	case(ESC_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 2) break;
+do_esc:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  refreshFileView();
 	  refreshDirView();
 	  endme = 1;
 	  break;
+	case('p'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_up;
 	case(UP_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_up:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //clear last selection
 	  fprintf(stdout, "\e[%d;9H%s", eSelect+4, editMenu[eSelect]);
 	  eSelect--;
 	  if(eSelect < 0) eSelect = eTotal-1;
-	  setScreenColors(BLUE, BGWHITE);
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;9H%s", eSelect+4, editMenu[eSelect]);
 	  fprintf(stdout, "\e[%d;22H", eSelect+4);
 	  break;
+	case('n'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_down;
 	case(DOWN_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_down:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //clear last selection
 	  fprintf(stdout, "\e[%d;9H%s", eSelect+4, editMenu[eSelect]);
 	  eSelect++;
 	  if(eSelect >= eTotal) eSelect = 0;
-	  setScreenColors(BLUE, BGWHITE);
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;9H%s", eSelect+4, editMenu[eSelect]);
 	  fprintf(stdout, "\e[%d;22H", eSelect+4);
@@ -306,34 +354,54 @@ void showEditMenu(int visible)
 	 if(ALT) 
 	 {
 	  activeWindow = DIR_WIN;
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  refreshFileView();
 	  refreshDirView();
 	  return;
 	 }
 	  break;
 	//case(ALT_F_KEY):	//navigate to File menu
+	case('b'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_left;
 	case('f'):
+	 if(CTRL)
+	   if(GNU_DOS_LEVEL > 1) goto do_right;
 	 if(!ALT) break;
 	case(LEFT_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_left:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  fprintf(log_file, "Opening file menu..\n");
 	  refreshFileView();
 	  refreshDirView();
 	  showFileMenu(YES);
 	  endme = 1;
 	  break;
-	//case(ALT_H_KEY):	//navigate to Help menu
 	case('h'):
-	 if(!ALT) break;
-	case(RIGHT_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(!ALT) break;
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  fprintf(log_file, "Opening help menu..\n");
 	  refreshFileView();
 	  refreshDirView();
 	  showHelpMenu(YES);
 	  endme = 1;
 	  break;
+	//case(ALT_H_KEY):	//navigate to Options menu
+	case('o'):
+	 if(!ALT) break;
+	 goto do_right;
+	case(RIGHT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_right:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  fprintf(log_file, "Opening options menu..\n");
+	  refreshFileView();
+	  refreshDirView();
+	  showOptionsMenu(YES);
+	  endme = 1;
+	  break;
 	case(ENTER_KEY):
 	  if(eSelect == 0) cutMarked();
 	  if(eSelect == 1) copyMarked();
@@ -346,11 +414,12 @@ void showEditMenu(int visible)
 	    findFile(); 
 	    scanDir(cwd); 
 	  }
-	  if(eSelect == 7) {
+	  if(eSelect == 7) 
+	  {
 	    showPropertiesDialog();
 	    scanDir(cwd); 
 	  }
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //activeWindow = DIR_WIN;
 	  refreshFileView();
 	  refreshDirView();
@@ -371,6 +440,160 @@ void showEditMenu(int visible)
 }
 
 
+/********************************************
+ * This procedure shows the OPTIONS menu under
+ * the main menu bar. It also takes control
+ * of the user input to navigate the menu
+ * with the arrow keys and to select menu
+ * items with ENTER. Pressing right or left
+ * arrows navigate to next menu on the left
+ * 'EDIT' and the right 'HELP' respectively.
+ * ******************************************/
+void showOptionsMenu(int visible)
+{
+  int i, ch, oSelect = 0;
+  int endme = 0;
+  if(visible == YES) 
+  {	//show the file menu
+    //activeWindow = HELP_MENU;
+    drawBox(3, 14, 6, 31, NULL, YES);
+    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+    fprintf(stdout, "\e[4;15H%s", optionsMenu[0]);
+    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+    for(i = 1; i < oTotal; i++) 
+      fprintf(stdout, "\e[%d;15H%s", i+4, optionsMenu[i]);
+    fprintf(stdout, "\e[4;30H");
+    while(!endme) 
+    {				//wait for user input
+      ch = getKey();
+      switch(ch) 
+      {
+	case('g'):
+	  if(GNU_DOS_LEVEL < 3) break;
+	  if(!CTRL) break;
+	  goto do_esc;
+	case(ESC_KEY):
+	  if(GNU_DOS_LEVEL > 2) break;
+do_esc:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  //setScreenColors(WHITE, BGBLUE);
+	  refreshFileView();
+	  refreshDirView();
+	  endme = 1;
+	  break;
+	case('p'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_up;
+	case(UP_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_up:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  //setScreenColors(WHITE, BGBLUE);
+	  fprintf(stdout, "\e[%d;15H%s", oSelect+4, optionsMenu[oSelect]);	//clear last selection
+	  oSelect --;
+	  if(oSelect < 0) oSelect = oTotal-1;
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+	  //setScreenColors(BLUE, BGWHITE);
+	  fprintf(stdout, "\e[%d;15H%s", oSelect+4, optionsMenu[oSelect]);	//highlight new selection
+	  fprintf(stdout, "\e[%d;30H", oSelect+4);
+	  fflush(stdout);
+	  break;
+	case('n'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_down;
+	case(DOWN_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_down:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  //setScreenColors(WHITE, BGBLUE);
+	  fprintf(stdout, "\e[%d;15H%s", oSelect+4, optionsMenu[oSelect]);	//clear last selection
+	  oSelect++;
+	  if(oSelect >= oTotal) oSelect = 0;
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+	  //setScreenColors(BLUE, BGWHITE);
+	  fprintf(stdout, "\e[%d;15H%s", oSelect+4, optionsMenu[oSelect]);	//highlight new selection
+	  fprintf(stdout, "\e[%d;30H", oSelect+4);
+	  fflush(stdout);
+	  break;
+	case('o'):	//hide the file menu and return control to main program
+	  if(!ALT) break;
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  //setScreenColors(WHITE, BGBLUE);
+	  refreshFileView();
+	  refreshDirView();
+	  return;
+	  break;
+	case('h'):	//navigate to Help menu
+	  if(!ALT) break;
+	  goto do_right;
+	case(RIGHT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_right:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  //setScreenColors(WHITE, BGBLUE);
+	  refreshFileView();
+	  refreshDirView();
+	  showHelpMenu(YES);
+	  endme = 1;
+	  break;
+	case('f'):	//navigate to File menu
+	  if(CTRL && GNU_DOS_LEVEL > 1) goto do_right;
+	  if(!ALT) break;
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  //setScreenColors(WHITE, BGBLUE);
+	  refreshFileView();
+	  refreshDirView();
+	  showFileMenu(YES);
+	  endme = 1;
+	  break;
+	case('e'):	//navigate to Edit menu
+	  if(!ALT) break;
+	  goto do_left;
+	case('b'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_left;
+	case(LEFT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_left:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  //setScreenColors(WHITE, BGBLUE);
+	  refreshFileView();
+	  refreshDirView();
+	  showEditMenu(YES);
+	  endme = 1;
+	  break;
+	case(ENTER_KEY):
+	  if(oSelect == 0) 
+	  {			//selected 'Change colors'
+	    optionsMenu_Change_Colors();
+	  }
+	  else if(oSelect == 1) 
+	  {			//selected 'Reset config'
+	    optionsMenu_Reset_Config();
+	  }
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  //setScreenColors(WHITE, BGBLUE);
+	  refreshFileView();
+	  refreshDirView();
+	  //refreshBottomView();
+	  endme = 1;
+	  break;
+	  //return;
+      }
+    }
+  } 
+  else 
+  {		//hide the options menu
+    refreshFileView();
+    refreshDirView();
+    return;
+  }
+}
+
+
 /********************************************
  * This procedure shows the HELP menu under
  * the main menu bar. It also takes control
@@ -378,7 +601,7 @@ void showEditMenu(int visible)
  * with the arrow keys and to select menu
  * items with ENTER. Pressing right or left
  * arrows navigate to next menu on the left
- * 'EDIT' and the right 'FILE' respectively.
+ * 'OPTIONS' and the right 'FILE' respectively.
  * ******************************************/
 void showHelpMenu(int visible) 
 {
@@ -387,79 +610,117 @@ void showHelpMenu(int visible)
   if(visible == YES) 
   {	//show the file menu
     //activeWindow = HELP_MENU;
-    drawBox(3, 14, 8, 31, NULL, YES);
-    setScreenColors(BLUE, BGWHITE);
-    fprintf(stdout, "\e[4;15H%s", helpMenu[0]);
-    setScreenColors(WHITE, BGBLUE);
+    drawBox(3, 23, 8, 40, NULL, YES);
+    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+    fprintf(stdout, "\e[4;24H%s", helpMenu[0]);
+    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
     for(i = 1; i < hTotal; i++) 
-      fprintf(stdout, "\e[%d;15H%s", i+4, helpMenu[i]);
-    fprintf(stdout, "\e[4;30H");
+      fprintf(stdout, "\e[%d;24H%s", i+4, helpMenu[i]);
+    fprintf(stdout, "\e[4;39H");
     while(!endme) 
     {				//wait for user input
       ch = getKey();
       switch(ch) 
       {
+	case('g'):
+	  if(GNU_DOS_LEVEL < 3) break;
+	  if(!CTRL) break;
+	  goto do_esc;
 	case(ESC_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 2) break;
+do_esc:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  refreshFileView();
 	  refreshDirView();
 	  endme = 1;
 	  break;
+	case('p'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_up;
 	case(UP_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_up:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //clear last selection
-	  fprintf(stdout, "\e[%d;15H%s", hSelect+4, helpMenu[hSelect]);
+	  fprintf(stdout, "\e[%d;24H%s", hSelect+4, helpMenu[hSelect]);
 	  hSelect--;
 	  if(hSelect < 0) hSelect = hTotal-1;
-	  setScreenColors(BLUE, BGWHITE);
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	  //highlight new selection
-	  fprintf(stdout, "\e[%d;15H%s", hSelect+4, helpMenu[hSelect]);
-	  fprintf(stdout, "\e[%d;30H", hSelect+4);
+	  fprintf(stdout, "\e[%d;24H%s", hSelect+4, helpMenu[hSelect]);
+	  fprintf(stdout, "\e[%d;39H", hSelect+4);
 	  break;
+	case('n'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_down;
 	case(DOWN_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_down:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  //clear last selection
-	  fprintf(stdout, "\e[%d;15H%s", hSelect+4, helpMenu[hSelect]);
+	  fprintf(stdout, "\e[%d;24H%s", hSelect+4, helpMenu[hSelect]);
 	  hSelect++;
 	  if(hSelect >= hTotal) hSelect = 0;
-	  setScreenColors(BLUE, BGWHITE);
+	  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
 	  //highlight new selection
-	  fprintf(stdout, "\e[%d;15H%s", hSelect+4, helpMenu[hSelect]);
-	  fprintf(stdout, "\e[%d;30H", hSelect+4);
+	  fprintf(stdout, "\e[%d;24H%s", hSelect+4, helpMenu[hSelect]);
+	  fprintf(stdout, "\e[%d;39H", hSelect+4);
 	  break;
 	//case(ALT_H_KEY)://hide help menu and return control to main program
 	case('h'):
 	 if(ALT) 
 	 {
 	  activeWindow = DIR_WIN;
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  refreshFileView();
 	  refreshDirView();
 	  return;
 	 }
-	  break;
+	 break;
 	//case(ALT_F_KEY):	//navigate to File menu
 	case('f'):
+	 if(CTRL && GNU_DOS_LEVEL > 1) goto do_right;
 	 if(!ALT) break;
+	 goto do_right;
 	case(RIGHT_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(GNU_DOS_LEVEL > 1) break;
+do_right:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  fprintf(log_file, "Opening file menu..\n");
 	  refreshFileView();
 	  refreshDirView();
 	  showFileMenu(YES);
 	  endme = 1;
 	  break;
-	//case(ALT_E_KEY):	//navigate to Edit menu
 	case('e'):
-	 if(!ALT) break;
-	case(LEFT_KEY):
-	  setScreenColors(WHITE, BGBLUE);
+	  if(!ALT) break;
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  fprintf(log_file, "Opening edit menu..\n");
 	  refreshFileView();
 	  refreshDirView();
 	  showEditMenu(YES);
 	  endme = 1;
 	  break;
+	//case(ALT_E_KEY):	//navigate to Options menu
+	case('o'):
+	 if(!ALT) break;
+	 goto do_left;
+	case('b'):
+	  if(GNU_DOS_LEVEL < 2) break;
+	  if(!CTRL) break;
+	  goto do_left;
+	case(LEFT_KEY):
+	  if(GNU_DOS_LEVEL > 1) break;
+do_left:
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+	  fprintf(log_file, "Opening options menu..\n");
+	  refreshFileView();
+	  refreshDirView();
+	  showOptionsMenu(YES);
+	  endme = 1;
+	  break;
 	case(ENTER_KEY):
 	  if(hSelect == 0) 
 	  {			//show README
@@ -473,8 +734,8 @@ void showHelpMenu(int visible)
 	  else if(hSelect == 3) 
 	  {		//show About msgbox
 	    fprintf(log_file, "Opening About dialog box..\n");
-	    char *x = " Prime for GNU/Linux. \n Developed by \
-Mohammed Isam, \n 2013, 2014. ";
+	    char *x = " Prime for GNU/Linux. \n Developed by "
+		      "Mohammed Isam, \n 2013, 2014. ";
 	    msgBox(x, OK, INFO);
 	  } 
 	  else if(hSelect == 2) 
@@ -484,7 +745,8 @@ Mohammed Isam, \n 2013, 2014. ";
 	    fprintf(stdout, "\e[4;7HBasic functions:");
 	    fprintf(stdout, "\e[5;9HSPACEBAR: Toggle select/unselect");
 	    fprintf(stdout, "\e[6;9HENTER: Navigate to directory");
-	fprintf(stdout, "\e[7;9HTAB: Navigate between dir/file view windows");
+	    fprintf(stdout, "\e[7;9HTAB: Navigate between dir/file "
+			    "view windows");
 	    fprintf(stdout, "\e[8;9HArrow keys: Navigate up/down");
 	    fprintf(stdout, "\e[10;7HEditing:");
 	    fprintf(stdout, "\e[11;9HDEL: Delete marked directories/files");
@@ -496,7 +758,7 @@ Mohammed Isam, \n 2013, 2014. ";
 	    fprintf(stdout, "\e[17;7HPress any key to continue..");
 	    do {;} while(!getKey());
 	  }
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  drawBox(1,1, SCREEN_H, SCREEN_W," Prime for GNU/Linux ",NO);
 	  drawMenuBar(2, 2, SCREEN_W-2);
 	  refreshFileView();
@@ -600,19 +862,39 @@ void showKeybindings()
   }
   
 readMore:
-  while(1) {
+  while(1) 
+  {
     ch = getKey();
-    switch(ch) {
+    switch(ch) 
+    {
+      case('g'):
+	if(GNU_DOS_LEVEL < 3) break;
+	if(!CTRL) break;
+	goto do_esc;
+      case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
       case(ENTER_KEY):
       case(SPACE_KEY):
-      case(ESC_KEY):
 	goto end;
 	break;
+      case('p'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_up;
       case(UP_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	if(firstVisLine == 0) break;	//can't go up--first line already
 	firstVisLine--;
 	break;
+      case('n'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_down;
       case(DOWN_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	if(!moreLines) break;	//reached last line
 	firstVisLine++;
 	break;
@@ -744,16 +1026,34 @@ readMore:
     ch = getKey();
     switch(ch) 
     {
+      case('g'):
+	if(GNU_DOS_LEVEL < 3) break;
+	if(!CTRL) break;
+	goto do_esc;
+      case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
       case(ENTER_KEY):
       case(SPACE_KEY):
-      case(ESC_KEY):
 	goto end;
 	break;
+      case('p'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_up;
       case(UP_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	if(firstVisLine == 0) break;	//can't go up--first line already
 	firstVisLine--;
 	break;
+      case('n'):
+	if(GNU_DOS_LEVEL < 2) break;
+	if(!CTRL) break;
+	goto do_down;
       case(DOWN_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	if(!moreLines) break;	//reached last line
 	firstVisLine++;
 	break;
