@@ -39,7 +39,7 @@ char *input_str;
 void refreshPropertiesDialog() 
 {
   //set the user interface
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   printf("\e[%d;%dH", x+1, y+2);
   if(activeWindow == DIR_WIN) printf("Dir name:  ");
   else printf("File name: ");
@@ -59,11 +59,11 @@ void refreshPropertiesDialog()
   printf("[ ] Write   [ ] Write   [ ] Write  ");
   printf("\e[%d;%dH", x+7, y+2);
   printf("[ ] Execute [ ] Execute [ ] Execute");
-  setScreenColors(WHITE, BGRED);
+  setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
   printf("\e[%d;%dH   OK   ", x+9, y+10);
   printf("\e[%d;%dH CANCEL ", x+9, y+22);
 
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   if(UREAD) { printf("\e[%d;%dHX", x+5, y+3); }
   if(UWRITE) { printf("\e[%d;%dHX", x+6, y+3); }
   if(UEXECUTE) { printf("\e[%d;%dHX", x+7, y+3); }
@@ -74,7 +74,7 @@ void refreshPropertiesDialog()
   if(OWRITE) { printf("\e[%d;%dHX", x+6, y+27); }
   if(OEXECUTE) { printf("\e[%d;%dHX", x+7, y+27); }
   
-  setScreenColors(BLUE, BGWHITE);
+  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
   if(sel == 0) {
     printf("\e[%d;%dH", x+1, y+13);
     if(strlen(input_str) > 26) 
@@ -101,10 +101,10 @@ void refreshPropertiesDialog()
   } else if(sel == 9) {
     printf("\e[%d;%dHExecute", x+7, y+30);
   } else if(sel == 10) {
-    setScreenColors(GREEN, BGRED);
+    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
     printf("\e[%d;%dH   OK   ", x+9, y+10);
   } else if(sel == 11) {
-    setScreenColors(GREEN, BGRED);
+    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
     printf("\e[%d;%dH CANCEL ", x+9, y+22);
   }//end if
   fflush(stdout);
@@ -143,7 +143,7 @@ void showPropertiesDialog()
   if(statbuf.st_mode & S_IXOTH) { OEXECUTE=1; }
 
   //draw window
-  setScreenColors(WHITE, BGBLUE);
+  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
   drawBox(x, y, x+h, w+y, " Properties ", YES);
   refreshPropertiesDialog();
 
@@ -157,26 +157,52 @@ void showPropertiesDialog()
     c = getKey();
     switch(c) 
     {
+      case('p'):
+	if(GNU_DOS_LEVEL > 1 && CTRL) goto do_up;
+	break;
       case(UP_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_up:
 	if(sel == 0) sel = 10;
 	else if(sel >= 10) sel = 7;
 	else if(sel >= 1 && sel <= 3) sel = 0;
 	else if(sel >= 4 && sel <= 9) sel -= 3;
 	break;
+      case('n'):
+	if(GNU_DOS_LEVEL > 1 && CTRL) goto do_down;
+	break;
       case(DOWN_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_down:
 	if(sel == 0) sel = 1;
 	else if(sel >= 10) sel = 0;
 	else if(sel >= 7 && sel <= 9) sel = 10;
 	else if(sel >= 1 && sel <= 6) sel += 3;
 	break;
+      case('f'):
+	if(GNU_DOS_LEVEL > 1 && CTRL) goto do_right;
+	break;
       case(RIGHT_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_right:
 	if(sel > 0) sel++;
 	if(sel > 11) sel = 0;
 	break;
+      case('b'):
+	if(GNU_DOS_LEVEL > 1 && CTRL) goto do_left;
+	break;
       case(LEFT_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_left:
 	if(sel > 0) sel--;
 	break;
+      case('g'):
+	if(GNU_DOS_LEVEL < 3) break;
+	if(!CTRL) break;
+	goto do_esc;
       case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	endme = 1;
 	break;
       case(SPACE_KEY):
@@ -185,7 +211,7 @@ void showPropertiesDialog()
 	{
 	  inputBoxI("Enter new name: ", input_str, " Rename... " );
 	  if(strlen(input)) { strcpy(input_str, input); NAME_CHANGED = 1; }
-	  setScreenColors(WHITE, BGBLUE);
+	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	  drawBox(x, y, x+h, w+y, " Properties ", YES);
 	} else if(sel == 1) UREAD=!UREAD;
 	else if(sel == 4) UWRITE=!UWRITE;
